@@ -22,13 +22,19 @@
  *  Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
  *  MA 02111-1307, USA
  */
+#include <config.h>
 
-#include "libglabels-private.h"
+#include "template.h"
 
+#include <glib/gi18n.h>
+#include <glib/gmem.h>
+#include <glib/gstrfuncs.h>
+#include <glib/gdir.h>
+#include <glib/gmessages.h>
 #include <string.h>
 
+#include "libglabels-private.h"
 #include "xml.h"
-#include "template.h"
 #include "xml-template.h"
 #include "paper.h"
 
@@ -128,7 +134,7 @@ gl_template_register (const glTemplate  *template)
 		g_free (abs_filename);
 
 	} else {
-		g_warning ("Cannot register new template with unknown page size.");
+		g_message ("Cannot register new template with unknown page size.");
 	}
 
 }
@@ -505,8 +511,8 @@ gl_template_add_markup (glTemplateLabelType *label_type,
 /* Create new layout structure.                                              */
 /*****************************************************************************/
 glTemplateLayout *
-gl_template_layout_new (gdouble nx,
-			gdouble ny,
+gl_template_layout_new (gint    nx,
+			gint    ny,
 			gdouble x0,
 			gdouble y0,
 			gdouble dx,
@@ -894,7 +900,7 @@ read_templates (void)
 	g_free (data_dir);
 
 	if (templates == NULL) {
-		g_warning (_("No template files found!"));
+		g_critical (_("Unable to locate any template files.  Libglabels may not be installed correctly!"));
 	}
 
 	return templates;
@@ -922,7 +928,7 @@ read_template_files_from_dir (GList       *templates,
 
 	dp = g_dir_open (dirname, 0, &gerror);
 	if (gerror != NULL) {
-	        g_warning ("cannot open data directory: %s", gerror->message );
+	        g_message ("cannot open data directory: %s", gerror->message );
 		return templates;
 	}
 
