@@ -26,7 +26,8 @@
 #ifndef __TEMPLATE_H__
 #define __TEMPLATE_H__
 
-#include <glib.h>
+#include <glib/gtypes.h>
+#include <glib/glist.h>
 
 G_BEGIN_DECLS
 
@@ -252,8 +253,8 @@ void                 gl_template_add_layout           (glTemplateLabelType *labe
 void                 gl_template_add_markup           (glTemplateLabelType *label_type,
 						       glTemplateMarkup    *markup);
 
-glTemplateLayout    *gl_template_layout_new           (gdouble              nx,
-						       gdouble              ny,
+glTemplateLayout    *gl_template_layout_new           (gint                 nx,
+						       gint                 ny,
 						       gdouble              x0,
 						       gdouble              y0,
 						       gdouble              dx,
