@@ -22,14 +22,18 @@
  *  Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
  *  MA 02111-1307, USA
  */
+#include <config.h>
 
-#include "libglabels-private.h"
+#include "xml-paper.h"
 
+#include <glib/gi18n.h>
+#include <glib/gmessages.h>
 #include <string.h>
 #include <libintl.h>
 
+#include "libglabels-private.h"
+
 #include "xml.h"
-#include "xml-paper.h"
 
 /*===========================================*/
 /* Private types                             */
@@ -43,10 +47,16 @@
 /* Local function prototypes                 */
 /*===========================================*/
 
-
-/*****************************************************************************/
-/* Read papers from paper file.                                              */
-/*****************************************************************************/
+
+/**
+ * gl_xml_paper_read_papers_from_file:
+ * @utf8_filename:       Filename of papers file (name encoded as UTF-8)
+ *
+ * Read paper definitions from a file.
+ *
+ * Returns: a list of #glPaper structures.
+ *
+ */
 GList *
 gl_xml_paper_read_papers_from_file (gchar *utf8_filename)
 {
@@ -58,13 +68,13 @@ gl_xml_paper_read_papers_from_file (gchar *utf8_filename)
 
 	filename = g_filename_from_utf8 (utf8_filename, -1, NULL, NULL, NULL);
 	if (!filename) {
-		g_warning ("Utf8 filename conversion error");
+		g_message ("Utf8 filename conversion error");
 		return NULL;
 	}
 
 	papers_doc = xmlParseFile (filename);
 	if (!papers_doc) {
-		g_warning ("\"%s\" is not a glabels paper file (not XML)",
+		g_message ("\"%s\" is not a glabels paper file (not XML)",
 			   filename);
 		return NULL;
 	}
@@ -77,9 +87,16 @@ gl_xml_paper_read_papers_from_file (gchar *utf8_filename)
 	return papers;
 }
 
-/*****************************************************************************/
-/* Read papers from paper xml doc tree.                                      */
-/*****************************************************************************/
+
+/**
+ * gl_xml_paper_parse_papers_doc:
+ * @papers_doc:  libxml #xmlDocPtr tree, representing a papers definition file.
+ *
+ * Read paper definitions from a libxml #xmlDocPtr tree.
+ *
+ * Returns: a list of #glPaper structures.
+ *
+ */
 GList *
 gl_xml_paper_parse_papers_doc (xmlDocPtr  papers_doc)
 {
@@ -91,13 +108,13 @@ gl_xml_paper_parse_papers_doc (xmlDocPtr  papers_doc)
 
 	root = xmlDocGetRootElement (papers_doc);
 	if (!root || !root->name) {
-		g_warning ("\"%s\" is not a glabels paper file (no root node)",
+		g_message ("\"%s\" is not a glabels paper file (no root node)",
 			   papers_doc->name);
 		xmlFreeDoc (papers_doc);
 		return papers;
 	}
-	if (!xmlStrEqual (root->name, "Glabels-paper-sizes")) {
-		g_warning ("\"%s\" is not a glabels paper file (wrong root node)",
+	if (!gl_xml_is_node (root, "Glabels-paper-sizes")) {
+		g_message ("\"%s\" is not a glabels paper file (wrong root node)",
 			   papers_doc->name);
 		xmlFreeDoc (papers_doc);
 		return papers;
@@ -105,13 +122,13 @@ gl_xml_paper_parse_papers_doc (xmlDocPtr  papers_doc)
 
 	for (node = root->xmlChildrenNode; node != NULL; node = node->next) {
 
-		if (xmlStrEqual (node->name, "Paper-size")) {
+		if (gl_xml_is_node (node, "Paper-size")) {
 			paper = gl_xml_paper_parse_paper_node (node);
 			papers = g_list_append (papers, paper);
 		} else {
 			if ( !xmlNodeIsText(node) ) {
-				if (!xmlStrEqual (node->name,"comment")) {
-					g_warning ("bad node =  \"%s\"",node->name);
+				if (!gl_xml_is_node (node, "comment")) {
+					g_message ("bad node =  \"%s\"",node->name);
 				}
 			}
 		}
@@ -120,9 +137,16 @@ gl_xml_paper_parse_papers_doc (xmlDocPtr  papers_doc)
 	return papers;
 }
 
-/*****************************************************************************/
-/* Parse XML paper Node.                                                     */
-/*****************************************************************************/
+
+/**
+ * gl_xml_paper_parse_paper_node:
+ * @paper_node:  libxml #xmlNodePtr paper node from a #xmlDocPtr tree.
+ *
+ * Read a single paper definition from a libxml #xmlNodePtr node.
+ *
+ * Returns: a pointer to a newly created #glPaper structure.
+ *
+ */
 glPaper *
 gl_xml_paper_parse_paper_node (xmlNodePtr paper_node)
 {
@@ -132,21 +156,9 @@ gl_xml_paper_parse_paper_node (xmlNodePtr paper_node)
 
 	LIBXML_TEST_VERSION;
 
-	id   = xmlGetProp (paper_node, "id");
+	id   = gl_xml_get_prop_string (paper_node, "id", NULL);
 
-	name = xmlGetProp (paper_node, "_name");
-	if (name != NULL) {
-
-		gchar *tmp = gettext (name);
-
-		if (tmp != name) {
-			g_free (name);
-			name = g_strdup (tmp);
-		}
-
-	} else {
-		name = xmlGetProp (paper_node, "name");
-	}
+	name = gl_xml_get_prop_i18n_string (paper_node, "name", NULL);
 
 	width  = gl_xml_get_prop_length (paper_node, "width", 0);
 	height = gl_xml_get_prop_length (paper_node, "height", 0);
