@@ -22,15 +22,19 @@
  *  Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
  *  MA 02111-1307, USA
  */
+#include <config.h>
 
-#include "libglabels-private.h"
+#include "xml-template.h"
 
+#include <glib/gi18n.h>
+#include <glib/gmessages.h>
 #include <string.h>
 #include <libintl.h>
 
+#include "libglabels-private.h"
+
 #include "paper.h"
 #include "xml.h"
-#include "xml-template.h"
 
 /*===========================================*/
 /* Private types                             */
@@ -80,9 +84,15 @@ static void  xml_create_alias_node          (const gchar                  *name,
 					     const xmlNsPtr                ns);
 
 
-/*****************************************************************************/
-/* Read templates from template file.                                        */
-/*****************************************************************************/
+/**
+ * gl_xml_template_read_templates_from_file:
+ * @utf8_filename:       Filename of papers file (name encoded as UTF-8)
+ *
+ * Read glabels templates from template file.
+ *
+ * Returns: a list of #glTemplate structures.
+ *
+ */
 GList *
 gl_xml_template_read_templates_from_file (const gchar *utf8_filename)
 {
@@ -94,13 +104,13 @@ gl_xml_template_read_templates_from_file (const gchar *utf8_filename)
 
 	filename = g_filename_from_utf8 (utf8_filename, -1, NULL, NULL, NULL);
 	if (!filename) {
-		g_warning ("Utf8 filename conversion error");
+		g_message ("Utf8 filename conversion error");
 		return NULL;
 	}
 
 	templates_doc = xmlParseFile (filename);
 	if (!templates_doc) {
-		g_warning ("\"%s\" is not a glabels template file (not XML)",
+		g_message ("\"%s\" is not a glabels template file (not XML)",
 		      filename);
 		return templates;
 	}
@@ -113,9 +123,16 @@ gl_xml_template_read_templates_from_file (const gchar *utf8_filename)
 	return templates;
 }
 
-/*****************************************************************************/
-/* Read templates from templates xml doc tree.                               */
-/*****************************************************************************/
+
+/**
+ * gl_xml_template_parse_templates_doc:
+ * @templates_doc:  libxml #xmlDocPtr tree, representing template file.
+ *
+ * Read glabels templates from a libxml #xmlDocPtr tree.
+ *
+ * Returns: a list of #glTemplate structures.
+ *
+ */
 GList *
 gl_xml_template_parse_templates_doc (const xmlDocPtr templates_doc)
 {
@@ -128,25 +145,25 @@ gl_xml_template_parse_templates_doc (const xmlDocPtr templates_doc)
 
 	root = xmlDocGetRootElement (templates_doc);
 	if (!root || !root->name) {
-		g_warning ("\"%s\" is not a glabels template file (no root node)",
+		g_message ("\"%s\" is not a glabels template file (no root node)",
 			   templates_doc->URL);
 		return templates;
 	}
-	if (!xmlStrEqual (root->name, "Glabels-templates")) {
-		g_warning ("\"%s\" is not a glabels template file (wrong root node)",
+	if (!gl_xml_is_node (root, "Glabels-templates")) {
+		g_message ("\"%s\" is not a glabels template file (wrong root node)",
 		      templates_doc->URL);
 		return templates;
 	}
 
 	for (node = root->xmlChildrenNode; node != NULL; node = node->next) {
 
-		if (xmlStrEqual (node->name, "Template")) {
+		if (gl_xml_is_node (node, "Template")) {
 			template = gl_xml_template_parse_template_node (node);
 			templates = g_list_append (templates, template);
 		} else {
 			if ( !xmlNodeIsText(node) ) {
-				if (!xmlStrEqual (node->name,"comment")) {
-					g_warning ("bad node =  \"%s\"",node->name);
+				if (!gl_xml_is_node (node,"comment")) {
+					g_message ("bad node =  \"%s\"",node->name);
 				}
 			}
 		}
@@ -155,9 +172,16 @@ gl_xml_template_parse_templates_doc (const xmlDocPtr templates_doc)
 	return templates;
 }
 
-/*****************************************************************************/
-/* Parse XML template Node.                                                  */
-/*****************************************************************************/
+
+/**
+ * gl_xml_template_parse_template_node:
+ * @template_node:  libxml #xmlNodePtr template node from a #xmlDocPtr tree.
+ *
+ * Read a single glabels template from a libxml #xmlNodePtr node.
+ *
+ * Returns: a pointer to a newly created #glTemplate structure.
+ *
+ */
 glTemplate *
 gl_xml_template_parse_template_node (const xmlNodePtr template_node)
 {
@@ -169,23 +193,10 @@ gl_xml_template_parse_template_node (const xmlNodePtr template_node)
 	glTemplate            *template;
 	xmlNodePtr             node;
 
-	name  = xmlGetProp (template_node, "name");
+	name = gl_xml_get_prop_string (template_node, "name", NULL);
+	description = gl_xml_get_prop_i18n_string (template_node, "description", NULL);
+	page_size = gl_xml_get_prop_string (template_node, "size", NULL);
 
-	description = xmlGetProp (template_node, "_description");
-	if (description != NULL) {
-
-		gchar *tmp = gettext (description);
-
-		if (tmp != description) {
-			g_free (description);
-			description = g_strdup (tmp);
-		}
-
-	} else {
-		description = xmlGetProp (template_node, "description");
-	}
-
-	page_size = xmlGetProp (template_node, "size");
 	if (gl_paper_is_id_other (page_size)) {
 
 		page_width = gl_xml_get_prop_length (template_node, "width", 0);
@@ -196,7 +207,7 @@ gl_xml_template_parse_template_node (const xmlNodePtr template_node)
 		if (paper == NULL) {
 			/* This should always be an id, but just in case a name
 			   slips by! */
-			g_warning (_("Unknown page size id \"%s\", trying as name"),
+			g_message (_("Unknown page size id \"%s\", trying as name"),
 				   page_size);
 			paper = gl_paper_from_name (page_size);
 			g_free (page_size);
@@ -206,7 +217,7 @@ gl_xml_template_parse_template_node (const xmlNodePtr template_node)
 			page_width  = paper->width;
 			page_height = paper->height;
 		} else {
-			g_warning (_("Unknown page size id or name \"%s\""),
+			g_message (_("Unknown page size id or name \"%s\""),
 				   page_size);
 		}
 		gl_paper_free (paper);
@@ -220,23 +231,27 @@ gl_xml_template_parse_template_node (const xmlNodePtr template_node)
 
 	for (node = template_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
-		if (xmlStrEqual (node->name, "Label-rectangle")) {
+		if (gl_xml_is_node (node, "Label-rectangle")) {
 			xml_parse_label_rectangle_node (node, template);
-		} else if (xmlStrEqual (node->name, "Label-round")) {
+		} else if (gl_xml_is_node (node, "Label-round")) {
 			xml_parse_label_round_node (node, template);
-		} else if (xmlStrEqual (node->name, "Label-cd")) {
+		} else if (gl_xml_is_node (node, "Label-cd")) {
 			xml_parse_label_cd_node (node, template);
-		} else if (xmlStrEqual (node->name, "Alias")) {
+		} else if (gl_xml_is_node (node, "Alias")) {
 			xml_parse_alias_node (node, template);
 		} else {
 			if (!xmlNodeIsText (node)) {
-				if (!xmlStrEqual (node->name,"comment")) {
-					g_warning ("bad node =  \"%s\"",node->name);
+				if (!gl_xml_is_node (node,"comment")) {
+					g_message ("bad node =  \"%s\"",node->name);
 				}
 			}
 		}
 	}
 
+	g_free (name);
+	g_free (description);
+	g_free (page_size);
+
 	return template;
 }
 
@@ -254,9 +269,9 @@ xml_parse_label_rectangle_node (xmlNodePtr  label_node,
 	glTemplateLabelType *label_type;
 	xmlNodePtr           node;
 
-	id      = xmlGetProp (label_node, "id");
+	id      = gl_xml_get_prop_string (label_node, "id", NULL);
 
-	if (tmp = xmlGetProp (label_node, "waste")) {
+	if (tmp = gl_xml_get_prop_string (label_node, "waste", NULL)) {
 		/* Handle single "waste" property. */
 		x_waste = y_waste = gl_xml_get_prop_length (label_node, "waste", 0);
 		g_free (tmp);
@@ -269,26 +284,27 @@ xml_parse_label_rectangle_node (xmlNodePtr  label_node,
 	h       = gl_xml_get_prop_length (label_node, "height", 0);
 	r       = gl_xml_get_prop_length (label_node, "round", 0);
 
-	label_type = gl_template_rect_label_type_new (id, w, h, r, x_waste, y_waste);
+	label_type = gl_template_rect_label_type_new ((gchar *)id, w, h, r, x_waste, y_waste);
 	gl_template_add_label_type (template, label_type);
 
 	for (node = label_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
-		if (xmlStrEqual (node->name, "Layout")) {
+		if (gl_xml_is_node (node, "Layout")) {
 			xml_parse_layout_node (node, label_type);
-		} else if (xmlStrEqual (node->name, "Markup-margin")) {
+		} else if (gl_xml_is_node (node, "Markup-margin")) {
 			xml_parse_markup_margin_node (node, label_type);
-		} else if (xmlStrEqual (node->name, "Markup-line")) {
+		} else if (gl_xml_is_node (node, "Markup-line")) {
 			xml_parse_markup_line_node (node, label_type);
-		} else if (xmlStrEqual (node->name, "Markup-circle")) {
+		} else if (gl_xml_is_node (node, "Markup-circle")) {
 			xml_parse_markup_circle_node (node, label_type);
 		} else if (!xmlNodeIsText (node)) {
-			if (!xmlStrEqual (node->name,"comment")) {
-				g_warning ("bad node =  \"%s\"",node->name);
+			if (!gl_xml_is_node (node, "comment")) {
+				g_message ("bad node =  \"%s\"",node->name);
 			}
 		}
 	}
 
+	g_free (id);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -304,30 +320,31 @@ xml_parse_label_round_node (xmlNodePtr  label_node,
 	glTemplateLabelType *label_type;
 	xmlNodePtr           node;
 
-	id    = xmlGetProp (label_node, "id");
+	id    = gl_xml_get_prop_string (label_node, "id", NULL);
 	waste = gl_xml_get_prop_length (label_node, "waste", 0);
 	r     = gl_xml_get_prop_length (label_node, "radius", 0);
 
-	label_type = gl_template_round_label_type_new (id, r, waste);
+	label_type = gl_template_round_label_type_new ((gchar *)id, r, waste);
 	gl_template_add_label_type (template, label_type);
 
 	for (node = label_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
-		if (xmlStrEqual (node->name, "Layout")) {
+		if (gl_xml_is_node (node, "Layout")) {
 			xml_parse_layout_node (node, label_type);
-		} else if (xmlStrEqual (node->name, "Markup-margin")) {
+		} else if (gl_xml_is_node (node, "Markup-margin")) {
 			xml_parse_markup_margin_node (node, label_type);
-		} else if (xmlStrEqual (node->name, "Markup-line")) {
+		} else if (gl_xml_is_node (node, "Markup-line")) {
 			xml_parse_markup_line_node (node, label_type);
-		} else if (xmlStrEqual (node->name, "Markup-circle")) {
+		} else if (gl_xml_is_node (node, "Markup-circle")) {
 			xml_parse_markup_circle_node (node, label_type);
 		} else if (!xmlNodeIsText (node)) {
-			if (!xmlStrEqual (node->name,"comment")) {
-				g_warning ("bad node =  \"%s\"",node->name);
+			if (!gl_xml_is_node (node, "comment")) {
+				g_message ("bad node =  \"%s\"",node->name);
 			}
 		}
 	}
 
+	g_free (id);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -343,33 +360,34 @@ xml_parse_label_cd_node (xmlNodePtr  label_node,
 	glTemplateLabelType *label_type;
 	xmlNodePtr           node;
 
-	id    = xmlGetProp (label_node, "id");
+	id    = gl_xml_get_prop_string (label_node, "id", NULL);
 	waste = gl_xml_get_prop_length (label_node, "waste", 0);
 	r1    = gl_xml_get_prop_length (label_node, "radius", 0);
 	r2    = gl_xml_get_prop_length (label_node, "hole", 0);
 	w     = gl_xml_get_prop_length (label_node, "width", 0);
 	h     = gl_xml_get_prop_length (label_node, "height", 0);
 
-	label_type = gl_template_cd_label_type_new (id, r1, r2, w, h, waste);
+	label_type = gl_template_cd_label_type_new ((gchar *)id, r1, r2, w, h, waste);
 	gl_template_add_label_type (template, label_type);
 
 	for (node = label_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
-		if (xmlStrEqual (node->name, "Layout")) {
+		if (gl_xml_is_node (node, "Layout")) {
 			xml_parse_layout_node (node, label_type);
-		} else if (xmlStrEqual (node->name, "Markup-margin")) {
+		} else if (gl_xml_is_node (node, "Markup-margin")) {
 			xml_parse_markup_margin_node (node, label_type);
-		} else if (xmlStrEqual (node->name, "Markup-line")) {
+		} else if (gl_xml_is_node (node, "Markup-line")) {
 			xml_parse_markup_line_node (node, label_type);
-		} else if (xmlStrEqual (node->name, "Markup-circle")) {
+		} else if (gl_xml_is_node (node, "Markup-circle")) {
 			xml_parse_markup_circle_node (node, label_type);
 		} else if (!xmlNodeIsText (node)) {
-			if (!xmlStrEqual (node->name,"comment")) {
-				g_warning ("bad node =  \"%s\"",node->name);
+			if (!gl_xml_is_node (node, "comment")) {
+				g_message ("bad node =  \"%s\"",node->name);
 			}
 		}
 	}
 
+	g_free (id);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -398,8 +416,8 @@ xml_parse_layout_node (xmlNodePtr              layout_node,
 	for (node = layout_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
 		if (!xmlNodeIsText (node)) {
-			if (!xmlStrEqual (node->name,"comment")) {
-				g_warning ("bad node =  \"%s\"",node->name);
+			if (!gl_xml_is_node (node, "comment")) {
+				g_message ("bad node =  \"%s\"",node->name);
 			}
 		}
 	}
@@ -424,8 +442,8 @@ xml_parse_markup_margin_node (xmlNodePtr              markup_node,
 	for (node = markup_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
 		if (!xmlNodeIsText (node)) {
-			if (!xmlStrEqual (node->name,"comment")) {
-				g_warning ("bad node =  \"%s\"",node->name);
+			if (!gl_xml_is_node (node, "comment")) {
+				g_message ("bad node =  \"%s\"",node->name);
 			}
 		}
 	}
@@ -453,8 +471,8 @@ xml_parse_markup_line_node (xmlNodePtr              markup_node,
 	for (node = markup_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
 		if (!xmlNodeIsText (node)) {
-			if (!xmlStrEqual (node->name,"comment")) {
-				g_warning ("bad node =  \"%s\"",node->name);
+			if (!gl_xml_is_node (node, "comment")) {
+				g_message ("bad node =  \"%s\"",node->name);
 			}
 		}
 	}
@@ -481,8 +499,8 @@ xml_parse_markup_circle_node (xmlNodePtr              markup_node,
 	for (node = markup_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
 		if (!xmlNodeIsText (node)) {
-			if (!xmlStrEqual (node->name,"comment")) {
-				g_warning ("bad node =  \"%s\"",node->name);
+			if (!gl_xml_is_node (node, "comment")) {
+				g_message ("bad node =  \"%s\"",node->name);
 			}
 		}
 	}
@@ -498,16 +516,21 @@ xml_parse_alias_node (xmlNodePtr  alias_node,
 {
 	gchar       *name;
 
-	name = xmlGetProp (alias_node, "name");
+	name = gl_xml_get_prop_string (alias_node, "name", NULL);
 
-	gl_template_add_alias (template, name);
+	gl_template_add_alias (template, (gchar *)name);
 
 	g_free (name);
 }
 
-/****************************************************************************/
-/* Write a list of templates to XML file.                                   */
-/****************************************************************************/
+/**
+ * gl_xml_template_write_templates_to_file:
+ * @templates:      List of #glTemplate structures
+ * @utf8_filename:  Filename of templates file (name encoded as UTF-8)
+ *
+ * Write a list of #glTemplate structures to a glabels XML template file.
+ *
+ */
 void
 gl_xml_template_write_templates_to_file (GList       *templates,
 					 const gchar *utf8_filename)
@@ -519,10 +542,10 @@ gl_xml_template_write_templates_to_file (GList       *templates,
 	glTemplate  *template;
 	gchar       *filename;
 
-	doc = xmlNewDoc ("1.0");
-	doc->xmlRootNode = xmlNewDocNode (doc, NULL, "Glabels-templates", NULL);
+	doc = xmlNewDoc ((xmlChar *)"1.0");
+	doc->xmlRootNode = xmlNewDocNode (doc, NULL, (xmlChar *)"Glabels-templates", NULL);
 
-	ns = xmlNewNs (doc->xmlRootNode, GL_XML_NAME_SPACE, NULL);
+	ns = xmlNewNs (doc->xmlRootNode, (xmlChar *)GL_XML_NAME_SPACE, NULL);
 	xmlSetNs (doc->xmlRootNode, ns);
 
 	for (p=templates; p!=NULL; p=p->next) {
@@ -532,14 +555,14 @@ gl_xml_template_write_templates_to_file (GList       *templates,
 
 	filename = g_filename_from_utf8 (utf8_filename, -1, NULL, NULL, NULL);
 	if (!filename)
-		g_warning (_("Utf8 conversion error."));
+		g_message (_("Utf8 conversion error."));
 	else {
 		xmlSetDocCompressMode (doc, 0);
 		xml_ret = xmlSaveFormatFile (filename, doc, TRUE);
 		xmlFreeDoc (doc);
 		if (xml_ret == -1) {
 
-			g_warning (_("Problem saving xml file."));
+			g_message (_("Problem saving xml file."));
 
 		}
 		g_free (filename);
@@ -547,9 +570,15 @@ gl_xml_template_write_templates_to_file (GList       *templates,
 
 }
 
-/****************************************************************************/
-/* Write single template to XML file.                                       */
-/****************************************************************************/
+
+/**
+ * gl_xml_template_write_template_to_file:
+ * @template:       #glTemplate structure to be written
+ * @utf8_filename:  Filename of templates file (name encoded as UTF-8)
+ *
+ * Write a single #glTemplate structures to a glabels XML template file.
+ *
+ */
 void
 gl_xml_template_write_template_to_file (const glTemplate  *template,
 					const gchar       *utf8_filename)
@@ -563,9 +592,16 @@ gl_xml_template_write_template_to_file (const glTemplate  *template,
 	g_list_free (templates);
 }
 
-/****************************************************************************/
-/* Add XML Template Node                                                    */
-/****************************************************************************/
+
+/**
+ * gl_xml_template_create_template_node:
+ * @template:       #glTemplate structure to be written
+ * @root:           parent node to receive new child node
+ * @ns:             a libxml #xmlNsPtr
+ *
+ * Add a single #glTemplate child node to given #xmlNodePtr.
+ *
+ */
 void
 gl_xml_template_create_template_node (const glTemplate *template,
 				      xmlNodePtr        root,
@@ -575,19 +611,19 @@ gl_xml_template_create_template_node (const glTemplate *template,
 	GList                  *p;
 	glTemplateLabelType    *label_type;
 
-	node = xmlNewChild (root, ns, "Template", NULL);
+	node = xmlNewChild (root, ns, (xmlChar *)"Template", NULL);
 
-	xmlSetProp (node, "name", template->name);
+	gl_xml_set_prop_string (node, "name", template->name);
 
-	xmlSetProp (node, "size", template->page_size);
-	if (xmlStrEqual (template->page_size, "Other")) {
+	gl_xml_set_prop_string (node, "size", template->page_size);
+	if (xmlStrEqual ((xmlChar *)template->page_size, (xmlChar *)"Other")) {
 
 		gl_xml_set_prop_length (node, "width", template->page_width);
 		gl_xml_set_prop_length (node, "height", template->page_height);
 
 	}
 
-	xmlSetProp (node, "description", template->description);
+	gl_xml_set_prop_string (node, "description", template->description);
 
 	for ( p=template->label_types; p != NULL; p=p->next ) {
 		label_type = (glTemplateLabelType *)p->data;
@@ -595,7 +631,7 @@ gl_xml_template_create_template_node (const glTemplate *template,
 	}
 
 	for ( p=template->aliases; p != NULL; p=p->next ) {
-		if (!xmlStrEqual (template->name, p->data)) {
+		if (!xmlStrEqual ((xmlChar *)template->name, (xmlChar *)p->data)) {
 			xml_create_alias_node ( p->data, node, ns );
 		}
 	}
@@ -618,27 +654,27 @@ xml_create_label_node (const glTemplateLabelType  *label_type,
 	switch (label_type->shape) {
 
 	case GL_TEMPLATE_SHAPE_RECT:
-		node = xmlNewChild(root, ns, "Label-rectangle", NULL);
-		xmlSetProp (node, "id", label_type->id);
-		gl_xml_set_prop_length (node, "width",  label_type->size.rect.w);
-		gl_xml_set_prop_length (node, "height", label_type->size.rect.h);
-		gl_xml_set_prop_length (node, "round",  label_type->size.rect.r);
-		gl_xml_set_prop_length (node, "x_waste",  label_type->size.rect.x_waste);
-		gl_xml_set_prop_length (node, "y_waste",  label_type->size.rect.y_waste);
+		node = xmlNewChild(root, ns, (xmlChar *)"Label-rectangle", NULL);
+		gl_xml_set_prop_string (node, "id",      label_type->id);
+		gl_xml_set_prop_length (node, "width",   label_type->size.rect.w);
+		gl_xml_set_prop_length (node, "height",  label_type->size.rect.h);
+		gl_xml_set_prop_length (node, "round",   label_type->size.rect.r);
+		gl_xml_set_prop_length (node, "x_waste", label_type->size.rect.x_waste);
+		gl_xml_set_prop_length (node, "y_waste", label_type->size.rect.y_waste);
 		break;
 
 	case GL_TEMPLATE_SHAPE_ROUND:
-		node = xmlNewChild(root, ns, "Label-round", NULL);
-		xmlSetProp (node, "id", label_type->id);
+		node = xmlNewChild(root, ns, (xmlChar *)"Label-round", NULL);
+		gl_xml_set_prop_string (node, "id",      label_type->id);
 		gl_xml_set_prop_length (node, "radius",  label_type->size.round.r);
 		gl_xml_set_prop_length (node, "waste",   label_type->size.round.waste);
 		break;
 
 	case GL_TEMPLATE_SHAPE_CD:
-		node = xmlNewChild(root, ns, "Label-cd", NULL);
-		xmlSetProp (node, "id", label_type->id);
-		gl_xml_set_prop_length (node, "radius",  label_type->size.cd.r1);
-		gl_xml_set_prop_length (node, "hole",    label_type->size.cd.r2);
+		node = xmlNewChild(root, ns, (xmlChar *)"Label-cd", NULL);
+		gl_xml_set_prop_string (node, "id",     label_type->id);
+		gl_xml_set_prop_length (node, "radius", label_type->size.cd.r1);
+		gl_xml_set_prop_length (node, "hole",   label_type->size.cd.r2);
 		if (label_type->size.cd.w != 0.0) {
 			gl_xml_set_prop_length (node, "width",  label_type->size.cd.w);
 		}
@@ -649,7 +685,7 @@ xml_create_label_node (const glTemplateLabelType  *label_type,
 		break;
 
 	default:
-		g_warning ("Unknown label style");
+		g_message ("Unknown label style");
 		return;
 		break;
 
@@ -668,7 +704,7 @@ xml_create_label_node (const glTemplateLabelType  *label_type,
 			xml_create_markup_circle_node (markup, node, ns);
 			break;
 		default:
-			g_warning ("Unknown markup type");
+			g_message ("Unknown markup type");
 			break;
 		}
 	}
@@ -690,7 +726,7 @@ xml_create_layout_node (const glTemplateLayout *layout,
 {
 	xmlNodePtr  node;
 
-	node = xmlNewChild(root, ns, "Layout", NULL);
+	node = xmlNewChild(root, ns, (xmlChar *)"Layout", NULL);
 	gl_xml_set_prop_int (node, "nx", layout->nx);
 	gl_xml_set_prop_int (node, "ny", layout->ny);
 	gl_xml_set_prop_length (node, "x0", layout->x0);
@@ -710,7 +746,7 @@ xml_create_markup_margin_node (const glTemplateMarkup  *markup,
 {
 	xmlNodePtr  node;
 
-	node = xmlNewChild(root, ns, "Markup-margin", NULL);
+	node = xmlNewChild(root, ns, (xmlChar *)"Markup-margin", NULL);
 
 	gl_xml_set_prop_length (node, "size", markup->data.margin.size);
 
@@ -726,7 +762,7 @@ xml_create_markup_line_node (const glTemplateMarkup *markup,
 {
 	xmlNodePtr  node;
 
-	node = xmlNewChild(root, ns, "Markup-line", NULL);
+	node = xmlNewChild(root, ns, (xmlChar *)"Markup-line", NULL);
 
 	gl_xml_set_prop_length (node, "x1", markup->data.line.x1);
 	gl_xml_set_prop_length (node, "y1", markup->data.line.y1);
@@ -745,7 +781,7 @@ xml_create_markup_circle_node (const glTemplateMarkup *markup,
 {
 	xmlNodePtr  node;
 
-	node = xmlNewChild(root, ns, "Markup-circle", NULL);
+	node = xmlNewChild(root, ns, (xmlChar *)"Markup-circle", NULL);
 
 	gl_xml_set_prop_length (node, "x0",     markup->data.circle.x0);
 	gl_xml_set_prop_length (node, "y0",     markup->data.circle.y0);
@@ -763,8 +799,8 @@ xml_create_alias_node (const gchar      *name,
 {
 	xmlNodePtr node;
 
-	node = xmlNewChild (root, ns, "Alias", NULL);
-	xmlSetProp (node, "name", name);
+	node = xmlNewChild (root, ns, (xmlChar *)"Alias", NULL);
+	gl_xml_set_prop_string (node, "name", name);
 
 }
 
