@@ -176,9 +176,6 @@ postnet_code (const gchar *digits)
 			len++;
 		}
 	}
-	if ((len != 5) && (len != 9) && (len != 11)) {
-		g_message ("Invalid POSTNET length %d, should be 5(ZIP), 9(ZIP+4), or 11(DPBC)", len);
-	}
 
 	/* Create correction character */
 	d = (10 - (sum % 10)) % 10;
