@@ -69,6 +69,22 @@ gl_color_from_gdk_color (GdkColor *gdk_color)
 	return color;
 }
 
+/*****************************************************************************/
+/* Resolve actual shadow color by adjusting opacity.                         */
+/*****************************************************************************/
+guint
+gl_color_shadow (guint   base_color,
+		 gdouble opacity,
+		 guint   object_color)
+{
+	guint color;
+
+	color = gl_color_set_opacity (base_color,
+				      opacity * GL_COLOR_F_ALPHA (object_color));
+
+	return color;
+}
+
 /****************************************************************************/
 /* Create a single color node with default color.                           */
 /****************************************************************************/
