@@ -37,9 +37,11 @@ typedef struct {
 #define GL_COLOR(r,g,b)     GNOME_CANVAS_COLOR(r,g,b)
 #define GL_COLOR_A(r,g,b,a) GNOME_CANVAS_COLOR_A(r,g,b,a)
 
-#define GL_COLOR_NONE GL_COLOR_A(0,0,0,0)
-#define GL_COLOR_FILL_MERGE_DEFAULT GL_COLOR_A(255,255,255,128)
-#define GL_COLOR_MERGE_DEFAULT      GL_COLOR_A(0,0,0,128)
+#define GL_COLOR_NONE                  GL_COLOR_A(0,0,0,0)
+#define GL_COLOR_FILL_MERGE_DEFAULT    GL_COLOR_A(255,255,255,128)
+#define GL_COLOR_MERGE_DEFAULT         GL_COLOR_A(0,0,0,128)
+#define GL_COLOR_SHADOW_DEFAULT        GL_COLOR(0,0,0)
+#define GL_COLOR_SHADOW_MERGE_DEFAULT  GL_COLOR_A(0,0,0,255)
 
 #define GL_COLOR_I_RED(x)   (((x)>>24) & 0xff)
 #define GL_COLOR_I_GREEN(x) (((x)>>16) & 0xff)
@@ -56,6 +58,10 @@ guint     gl_color_set_opacity (guint color, gdouble opacity);
 GdkColor *gl_color_to_gdk_color   (guint     color);
 guint     gl_color_from_gdk_color (GdkColor *gdk_color);
 
+guint     gl_color_shadow (guint   base_color,
+			   gdouble opacity,
+			   guint   object_color);
+
 glColorNode *gl_color_node_new_default    ();
 
 glColorNode *gl_color_node_dup            (glColorNode     *color_node);
