@@ -30,7 +30,7 @@
 #ifndef __DEBUG_H__
 #define __DEBUG_H__
 
-#include <glib.h>
+#include <glib/gtypes.h>
 
 G_BEGIN_DECLS
 
