@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
@@ -22,11 +24,16 @@
 
 #include <config.h>
 
-#include <gnome.h>
+#include "file.h"
+
+#include <glib/gi18n.h>
+#include <gtk/gtkdialog.h>
+#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtkfilechooserdialog.h>
+#include <gtk/gtkstock.h>
 #include <string.h>
 
 #include "xml-label.h"
-#include "file.h"
 #include "recent.h"
 #include "hig.h"
 #include "util.h"
@@ -50,14 +57,14 @@ static gchar *save_path = NULL;
 /*===========================================*/
 /* Local function prototypes.                */
 /*===========================================*/
-static void create_new_dialog_widgets        (glHigDialog       *dlg);
+static void create_new_dialog_widgets        (GtkDialog         *dlg);
 static void new_template_changed             (glWdgtMediaSelect *select,
 					      gpointer           data);
 static void new_response                     (GtkDialog         *dlg,
 					      gint               response,
 					      gpointer           user_data);
 
-static void create_properties_dialog_widgets (glHigDialog       *dlg,
+static void create_properties_dialog_widgets (GtkDialog         *dlg,
 					      glLabel           *label);
 static void properties_template_changed      (glWdgtMediaSelect *select,
 					      gpointer           data);
@@ -65,31 +72,19 @@ static void properties_response              (GtkDialog         *dlg,
 					      gint               response,
 					      gpointer           user_data);
 
-#ifdef HAVE_FILE_CHOOSER
 static void open_response                    (GtkDialog         *chooser,
 					      gint               response,
-					      GtkWindow         *window);
+					      glWindow          *window);
 static void save_as_response                 (GtkDialog         *chooser,
 					      gint               response,
 					      glLabel           *label);
-#else
-static void open_ok                          (GtkWidget         *widget,
-					      GtkFileSelection  *fsel);
-static void save_as_ok_cb                    (GtkWidget         *widget,
-					      GtkFileSelection  *fsel);
-static void save_as_cancel_cb                (GtkWidget         *widget,
-					      GtkFileSelection  *fsel);
-static void save_as_destroy_cb               (GtkWidget         *widget,
-					      gboolean          *destroy_flag);
-#endif
-
 
 
 /*****************************************************************************/
 /* "New" menu callback.                                                      */
 /*****************************************************************************/
 void
-gl_file_new (GtkWindow *window)
+gl_file_new (glWindow  *window)
 {
 	GtkWidget    *dlg;
 
@@ -97,16 +92,17 @@ gl_file_new (GtkWindow *window)
 
 	g_return_if_fail (window != NULL);
 
-	dlg = gl_hig_dialog_new_with_buttons (_("New Label or Card"),
-					      window,
-					      GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					      GTK_STOCK_OK, GTK_RESPONSE_OK,
-					      NULL);
+	dlg = gtk_dialog_new_with_buttons (_("New Label or Card"),
+					   GTK_WINDOW (window),
+					   GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_NO_SEPARATOR,
+					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					   GTK_STOCK_OK, GTK_RESPONSE_OK,
+					   NULL);
 
 	gtk_dialog_set_default_response	(GTK_DIALOG (dlg), GTK_RESPONSE_OK);
+	gtk_container_set_border_width (GTK_CONTAINER(dlg), GL_HIG_PAD2);
 
-	create_new_dialog_widgets (GL_HIG_DIALOG (dlg));
+	create_new_dialog_widgets (GTK_DIALOG (dlg));
 
 	g_object_set_data (G_OBJECT (dlg), "parent_window", window);
 
@@ -123,20 +119,23 @@ gl_file_new (GtkWindow *window)
 /* PRIVATE.  Create widgets.                                                 */
 /*---------------------------------------------------------------------------*/
 static void
-create_new_dialog_widgets (glHigDialog *dlg)
+create_new_dialog_widgets (GtkDialog *dlg)
 {
-	GtkWidget *wframe, *template_entry, *rotate_sel;
+	GtkWidget *wvbox, *wframe, *template_entry, *rotate_sel;
 
 	gl_debug (DEBUG_FILE, "START");
 
+	wvbox = gtk_vbox_new (FALSE, GL_HIG_PAD2);
+	gtk_box_pack_start (GTK_BOX(dlg->vbox), wvbox, FALSE, FALSE, 0);
+
 	wframe = gl_hig_category_new (_("Media Type"));
-	gl_hig_dialog_add_widget (dlg, wframe);
+	gtk_box_pack_start (GTK_BOX (wvbox), wframe, FALSE, FALSE, 0);
 
 	template_entry = gl_wdgt_media_select_new ();
 	gl_hig_category_add_widget (GL_HIG_CATEGORY(wframe), template_entry);
 
 	wframe = gl_hig_category_new (_("Label orientation"));
-	gl_hig_dialog_add_widget (dlg, wframe);
+	gtk_box_pack_start (GTK_BOX (wvbox), wframe, FALSE, FALSE, 0);
 
 	rotate_sel = gl_wdgt_rotate_label_new ();
 	gl_hig_category_add_widget (GL_HIG_CATEGORY(wframe), rotate_sel);
@@ -232,6 +231,8 @@ new_response (GtkDialog *dlg,
 		gl_label_set_template (label, template);
 		gl_label_set_rotate_flag (label, rotate_flag);
 
+		gl_template_free (template);
+
 		window =
 			GL_WINDOW (g_object_get_data (G_OBJECT (dlg),
 						      "parent_window"));
@@ -257,7 +258,7 @@ new_response (GtkDialog *dlg,
 /*****************************************************************************/
 void
 gl_file_properties (glLabel   *label,
-		    GtkWindow *window)
+		    glWindow  *window)
 {
 	GtkWidget    *dlg;
 
@@ -266,16 +267,17 @@ gl_file_properties (glLabel   *label,
 	g_return_if_fail (label && GL_IS_LABEL (label));
 	g_return_if_fail (window && GTK_IS_WINDOW (window));
 
-	dlg = gl_hig_dialog_new_with_buttons (_("Label properties"),
-					      window,
-					      GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					      GTK_STOCK_OK, GTK_RESPONSE_OK,
-					      NULL);
+	dlg = gtk_dialog_new_with_buttons (_("Label properties"),
+					   GTK_WINDOW (window),
+					   GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_NO_SEPARATOR,
+					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					   GTK_STOCK_OK, GTK_RESPONSE_OK,
+					   NULL);
+	gtk_container_set_border_width (GTK_CONTAINER(dlg), GL_HIG_PAD2);
 
 	gtk_dialog_set_default_response	(GTK_DIALOG (dlg), GTK_RESPONSE_OK);
 
-	create_properties_dialog_widgets (GL_HIG_DIALOG (dlg), label);
+	create_properties_dialog_widgets (GTK_DIALOG (dlg), label);
 
 	g_object_set_data (G_OBJECT (dlg), "label", label);
 
@@ -292,23 +294,26 @@ gl_file_properties (glLabel   *label,
 /* PRIVATE.  Create widgets.                                                 */
 /*---------------------------------------------------------------------------*/
 static void
-create_properties_dialog_widgets (glHigDialog *dlg,
+create_properties_dialog_widgets (GtkDialog   *dlg,
 				  glLabel     *label)
 {
-	GtkWidget  *wframe, *template_entry, *rotate_sel;
+	GtkWidget  *wvbox, *wframe, *template_entry, *rotate_sel;
 	glTemplate *template;
 	gboolean    rotate_flag;
 
 	gl_debug (DEBUG_FILE, "START");
 
+	wvbox = gtk_vbox_new (FALSE, GL_HIG_PAD2);
+	gtk_box_pack_start (GTK_BOX(dlg->vbox), wvbox, FALSE, FALSE, 0);
+
 	wframe = gl_hig_category_new (_("Media Type"));
-	gl_hig_dialog_add_widget (dlg, wframe);
+	gtk_box_pack_start (GTK_BOX (wvbox), wframe, FALSE, FALSE, 0);
 
 	template_entry = gl_wdgt_media_select_new ();
 	gl_hig_category_add_widget (GL_HIG_CATEGORY(wframe), template_entry);
 
 	wframe = gl_hig_category_new (_("Label orientation"));
-	gl_hig_dialog_add_widget (dlg, wframe);
+	gtk_box_pack_start (GTK_BOX (wvbox), wframe, FALSE, FALSE, 0);
 
 	rotate_sel = gl_wdgt_rotate_label_new ();
 	gl_hig_category_add_widget (GL_HIG_CATEGORY(wframe), rotate_sel);
@@ -419,13 +424,11 @@ properties_response (GtkDialog *dlg,
 	gl_debug (DEBUG_FILE, "END");
 }
 
-#ifdef HAVE_FILE_CHOOSER
-
 /*****************************************************************************/
 /* "Open" menu callback.                                                     */
 /*****************************************************************************/
 void
-gl_file_open (GtkWindow *window)
+gl_file_open (glWindow  *window)
 {
 	GtkWidget     *chooser;
 	GtkFileFilter *filter;
@@ -435,7 +438,7 @@ gl_file_open (GtkWindow *window)
 	g_return_if_fail (window != NULL);
 
 	chooser = gtk_file_chooser_dialog_new ("Open label",
-					       window,
+					       GTK_WINDOW (window),
 					       GTK_FILE_CHOOSER_ACTION_OPEN,
 					       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -474,7 +477,7 @@ gl_file_open (GtkWindow *window)
 static void
 open_response (GtkDialog     *chooser,
 	       gint           response,
-	       GtkWindow     *window)
+	       glWindow      *window)
 {
 	gchar            *raw_filename;
 	gchar 		 *filename;
@@ -498,12 +501,14 @@ open_response (GtkDialog     *chooser,
 		    !filename || 
 		    g_file_test (raw_filename, G_FILE_TEST_IS_DIR)) {
 
-			dlg = gl_hig_alert_new (GTK_WINDOW(chooser),
-					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_MESSAGE_WARNING,
-					GTK_BUTTONS_CLOSE,
-					_("Empty file name selection"),
-					_("Please select a file or supply a valid file name"));
+			dlg = gtk_message_dialog_new (GTK_WINDOW(chooser),
+						      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						      GTK_MESSAGE_WARNING,
+						      GTK_BUTTONS_CLOSE,
+						      _("Empty file name selection"));
+			gtk_message_dialog_format_secondary_text (
+				GTK_MESSAGE_DIALOG (dlg),
+				_("Please select a file or supply a valid file name"));
 
 			gtk_dialog_run (GTK_DIALOG (dlg));
 			gtk_widget_destroy (dlg);
@@ -512,12 +517,14 @@ open_response (GtkDialog     *chooser,
 
 			if (!g_file_test (raw_filename, G_FILE_TEST_IS_REGULAR)) {
 
-				dlg = gl_hig_alert_new (GTK_WINDOW(chooser),
-						GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-						GTK_MESSAGE_WARNING,
-						GTK_BUTTONS_CLOSE,
-						_("File does not exist"),
-						_("Please select a file or supply a valid file name"));
+				dlg = gtk_message_dialog_new (GTK_WINDOW(chooser),
+							      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+							      GTK_MESSAGE_WARNING,
+							      GTK_BUTTONS_CLOSE,
+							      _("File does not exist"));
+				gtk_message_dialog_format_secondary_text (
+					GTK_MESSAGE_DIALOG (dlg),
+					_("Please select a file or supply a valid file name"));
 
 				gtk_dialog_run (GTK_DIALOG (dlg));
 				gtk_widget_destroy (dlg);
@@ -546,138 +553,21 @@ open_response (GtkDialog     *chooser,
 	gl_debug (DEBUG_FILE, "END");
 }
 
-#else
-
-/*****************************************************************************/
-/* "Open" menu callback.                                                     */
-/*****************************************************************************/
-void
-gl_file_open (GtkWindow *window)
-{
-	GtkFileSelection *fsel;
-
-	gl_debug (DEBUG_FILE, "START");
-
-	g_return_if_fail (window != NULL);
-
-	fsel = GTK_FILE_SELECTION (gtk_file_selection_new (_("Open")));
-	gtk_window_set_transient_for (GTK_WINDOW (fsel), window);
-	gtk_window_set_title (GTK_WINDOW (fsel), _("Open label"));
-
-	g_object_set_data (G_OBJECT (fsel), "parent_window", window);
-
-	g_signal_connect (G_OBJECT (fsel->ok_button), "clicked",
-			  G_CALLBACK (open_ok), fsel);
-
-	g_signal_connect_swapped (G_OBJECT (fsel->cancel_button), "clicked",
-				  G_CALLBACK (gtk_widget_destroy),
-				  G_OBJECT (fsel));
-
-	/* Recover state of open dialog */
-	if (open_path != NULL) {
-		gtk_file_selection_set_filename (fsel, open_path);
-	}
-
-	/* show the dialog */
-	gtk_widget_show (GTK_WIDGET (fsel));
-
-	gl_debug (DEBUG_FILE, "END");
-}
-
-/*---------------------------------------------------------------------------*/
-/* PRIVATE.  Open "O.K." button callback.                                    */
-/*---------------------------------------------------------------------------*/
-static void
-open_ok (GtkWidget        *widget,
-	 GtkFileSelection *fsel)
-{
-	gchar            *raw_filename;
-	gchar 		 *filename;
-	GtkWidget        *dlg;
-	gint              ret;
-	EggRecentModel 	 *recent;
-	GtkWindow        *window;
-
-	gl_debug (DEBUG_FILE, "START");
-
-	g_return_if_fail (GTK_IS_FILE_SELECTION (fsel));
-
-	/* get the filename */
-	raw_filename = g_strdup (gtk_file_selection_get_filename (fsel));
-	filename = g_filename_to_utf8 (raw_filename, -1, NULL, NULL, NULL);
-
-	if (!raw_filename || 
-	    !filename || 
-	    g_file_test (raw_filename, G_FILE_TEST_IS_DIR)) {
-
-		dlg = gl_hig_alert_new (GTK_WINDOW(fsel),
-					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_MESSAGE_WARNING,
-					GTK_BUTTONS_CLOSE,
-					_("Empty file name selection"),
-					_("Please select a file or supply a valid file name"));
-
-		gtk_dialog_run (GTK_DIALOG (dlg));
-		gtk_widget_destroy (dlg);
-
-	} else {
-
-		if (!g_file_test (raw_filename, G_FILE_TEST_IS_REGULAR)) {
-
-			dlg = gl_hig_alert_new (GTK_WINDOW(fsel),
-						GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-						GTK_MESSAGE_WARNING,
-						GTK_BUTTONS_CLOSE,
-						_("File does not exist"),
-						_("Please select a file or supply a valid file name"));
-
-			gtk_dialog_run (GTK_DIALOG (dlg));
-			gtk_widget_destroy (dlg);
-
-
-		} else {
-		
-			window = g_object_get_data (G_OBJECT(fsel),
-						    "parent_window");
-
-			if ( gl_file_open_real (filename, window) ) {
-				gtk_widget_destroy (GTK_WIDGET (fsel));
-			}
-
-		}
-
-	}
-
-	g_free (filename);
-	g_free (raw_filename);
-
-	gl_debug (DEBUG_FILE, "END");
-}
-#endif
 
 /*****************************************************************************/
 /* "Open recent" menu callback.                                              */
 /*****************************************************************************/
-gboolean
-gl_file_open_recent (EggRecentView   *view,
-		     EggRecentItem   *item,
-		     GtkWindow       *window)
+void
+gl_file_open_recent (const gchar     *filename,
+		     glWindow        *window)
 {
-	gboolean result = FALSE;
-	gchar *filename;
-	
 	gl_debug (DEBUG_FILE, "");
 
-	filename = gl_recent_get_filename (item);
-
 	if (filename) {
 		gl_debug (DEBUG_FILE, "open recent: %s", filename);
 
-		result = gl_file_open_real (filename, window);
-		g_free (filename);
+		gl_file_open_real (filename, window);
 	}
-
-	return result;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -685,7 +575,7 @@ gl_file_open_recent (EggRecentView   *view,
 /*---------------------------------------------------------------------------*/
 gboolean
 gl_file_open_real (const gchar     *filename,
-		   GtkWindow       *window)
+		   glWindow        *window)
 {
 	gchar            *abs_filename;
 	glLabel          *label;
@@ -700,21 +590,17 @@ gl_file_open_real (const gchar     *filename,
 	label = gl_xml_label_open (abs_filename, &status);
 	if (!label) {
 		GtkWidget *dlg;
-		gchar *primary_msg;
 
 		gl_debug (DEBUG_FILE, "couldn't open file");
 
-		primary_msg = g_strdup_printf (_("Could not open file \"%s\""),
-					       filename);
-
-		dlg = gl_hig_alert_new (window,
-					GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_MESSAGE_ERROR,
-					GTK_BUTTONS_CLOSE,
-					primary_msg,
-					_("Not a supported file format"));
-
-		g_free (primary_msg);
+		dlg = gtk_message_dialog_new (GTK_WINDOW (window),
+					      GTK_DIALOG_DESTROY_WITH_PARENT,
+					      GTK_MESSAGE_ERROR,
+					      GTK_BUTTONS_CLOSE,
+					      _("Could not open file \"%s\""),
+					      filename);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg),
+							  _("Not a supported file format"));
 
 		gtk_dialog_run (GTK_DIALOG (dlg));
 		gtk_widget_destroy (dlg);
@@ -739,10 +625,6 @@ gl_file_open_real (const gchar     *filename,
 		if (open_path != NULL)
 			g_free (open_path);
 		open_path = g_path_get_dirname (abs_filename);
-#ifndef HAVE_FILE_CHOOSER
-		if (open_path != NULL)
-			open_path = g_strconcat (open_path, "/", NULL);
-#endif
 		g_free (abs_filename);
 
 		gl_debug (DEBUG_FILE, "END true");
@@ -757,7 +639,7 @@ gl_file_open_real (const gchar     *filename,
 /*****************************************************************************/
 gboolean
 gl_file_save (glLabel   *label,
-	      GtkWindow *window)
+	      glWindow  *window)
 {
 	glXMLLabelStatus  status;
 	GError           *error = NULL;
@@ -789,25 +671,22 @@ gl_file_save (glLabel   *label,
 
 	if (status != XML_LABEL_OK)
 	{
-		GtkWidget *dialog;
-		gchar *primary_msg;
+		GtkWidget *dlg;
 
 		gl_debug (DEBUG_FILE, "FAILED");
 
-		primary_msg = g_strdup_printf (_("Could not save file \"%s\""),
-					       filename);
+		dlg = gtk_message_dialog_new (GTK_WINDOW (window),
+					      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					      GTK_MESSAGE_ERROR,
+					      GTK_BUTTONS_CLOSE,
+					      _("Could not save file \"%s\""),
+					      filename);
+		gtk_message_dialog_format_secondary_text (
+			GTK_MESSAGE_DIALOG (dlg),
+			_("Error encountered during save.  The file is still not saved."));
 
-		dialog = gl_hig_alert_new (window,
-					   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					   GTK_MESSAGE_ERROR,
-					   GTK_BUTTONS_CLOSE,
-					   primary_msg,
-					   _("Error encountered during save.  The file is still not saved."));
-
-		g_free (primary_msg);
-
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
+		gtk_dialog_run (GTK_DIALOG (dlg));
+		gtk_widget_destroy (dlg);
 
 		g_free (filename);
 
@@ -825,14 +704,12 @@ gl_file_save (glLabel   *label,
 	}
 }
 
-#ifdef HAVE_FILE_CHOOSER
-
 /*****************************************************************************/
 /* "Save As" menu callback.                                                  */
 /*****************************************************************************/
 gboolean
 gl_file_save_as (glLabel   *label,
-		 GtkWindow *window)
+		 glWindow  *window)
 {
 	GtkWidget        *chooser;
 	GtkFileFilter    *filter;
@@ -842,14 +719,14 @@ gl_file_save_as (glLabel   *label,
 	gl_debug (DEBUG_FILE, "START");
 
 	g_return_val_if_fail (label && GL_IS_LABEL(label), FALSE);
-	g_return_val_if_fail (window && GTK_IS_WINDOW(window), FALSE);
+	g_return_val_if_fail (window && GL_IS_WINDOW(window), FALSE);
 
 	name = gl_label_get_short_name (label);
 	title = g_strdup_printf (_("Save \"%s\" as"), name);
 	g_free (name);
 
 	chooser = gtk_file_chooser_dialog_new (title,
-					       window,
+					       GTK_WINDOW (window),
 					       GTK_FILE_CHOOSER_ACTION_SAVE,
 					       GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -908,7 +785,6 @@ save_as_response (GtkDialog     *chooser,
 	glXMLLabelStatus  status;
 	EggRecentModel   *recent;
 	gboolean         *saved_flag;
-	gchar            *primary_msg;
 	gboolean          cancel_flag = FALSE;
 
 	gl_debug (DEBUG_FILE, "START");
@@ -927,12 +803,14 @@ save_as_response (GtkDialog     *chooser,
 
 		if (!raw_filename || g_file_test (raw_filename, G_FILE_TEST_IS_DIR)) {
 
-			dlg = gl_hig_alert_new (GTK_WINDOW(chooser),
-					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_MESSAGE_WARNING,
-					GTK_BUTTONS_CLOSE,
-					_("Empty file name selection"),
-					_("Please supply a valid file name"));
+			dlg = gtk_message_dialog_new (GTK_WINDOW(chooser),
+						      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						      GTK_MESSAGE_WARNING,
+						      GTK_BUTTONS_CLOSE,
+						      _("Empty file name selection"));
+			gtk_message_dialog_format_secondary_text (
+				GTK_MESSAGE_DIALOG (dlg),
+				_("Please supply a valid file name"));
 
 			gtk_dialog_run (GTK_DIALOG (dlg));
 			gtk_widget_destroy (dlg);
@@ -949,17 +827,15 @@ save_as_response (GtkDialog     *chooser,
 			if (g_file_test (full_filename, G_FILE_TEST_IS_REGULAR)) {
 				gint ret;
 
-				primary_msg = g_strdup_printf (_("Overwrite file \"%s\"?"),
+				dlg = gtk_message_dialog_new (GTK_WINDOW(chooser),
+							      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+							      GTK_MESSAGE_QUESTION,
+							      GTK_BUTTONS_YES_NO,
+							      _("Overwrite file \"%s\"?"),
 							       filename);
-
-				dlg = gl_hig_alert_new (GTK_WINDOW(chooser),
-						GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-						GTK_MESSAGE_QUESTION,
-						GTK_BUTTONS_YES_NO,
-						primary_msg,
-						_("File already exists."));
-			
-				g_free (primary_msg);
+				gtk_message_dialog_format_secondary_text (
+					GTK_MESSAGE_DIALOG (dlg),
+					_("File already exists."));
 
 				ret = gtk_dialog_run (GTK_DIALOG (dlg));
 				if ( ret == GTK_RESPONSE_NO ) {
@@ -976,17 +852,16 @@ save_as_response (GtkDialog     *chooser,
 
 				if ( status != XML_LABEL_OK ) {
 
-					primary_msg = g_strdup_printf (_("Could not save file \"%s\""),
-								       filename);
-
-					dlg = gl_hig_alert_new (GTK_WINDOW(chooser),
-							GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-							GTK_MESSAGE_ERROR,
-							GTK_BUTTONS_CLOSE,
-							primary_msg,
-							_("Error encountered during save.  The file is still not saved."));
-
-					g_free (primary_msg);
+					dlg = gtk_message_dialog_new (
+						GTK_WINDOW(chooser),
+						GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						GTK_MESSAGE_ERROR,
+						GTK_BUTTONS_CLOSE,
+						_("Could not save file \"%s\""),
+						filename);
+					gtk_message_dialog_format_secondary_text (
+						GTK_MESSAGE_DIALOG (dlg),
+						_("Error encountered during save.  The file is still not saved."));
 
 					gtk_dialog_run (GTK_DIALOG (dlg));
 					gtk_widget_destroy (dlg);
@@ -1025,221 +900,6 @@ save_as_response (GtkDialog     *chooser,
 	gl_debug (DEBUG_FILE, "END");
 }
 
-#else
-
-/*****************************************************************************/
-/* "Save As" menu callback.                                                  */
-/*****************************************************************************/
-gboolean
-gl_file_save_as (glLabel   *label,
-		 GtkWindow *window)
-{
-	GtkFileSelection *fsel;
-	gboolean          saved_flag = FALSE;
-	gboolean          destroy_flag = FALSE;
-	gchar            *name, *title;
-
-	gl_debug (DEBUG_FILE, "START");
-
-	g_return_val_if_fail (label && GL_IS_LABEL(label), FALSE);
-	g_return_val_if_fail (window && GTK_IS_WINDOW(window), FALSE);
-
-	name = gl_label_get_short_name (label);
-	title = g_strdup_printf (_("Save \"%s\" as"), name);
-	g_free (name);
-
-	fsel = GTK_FILE_SELECTION (gtk_file_selection_new (title));
-	gtk_window_set_modal (GTK_WINDOW (fsel), TRUE);
-	gtk_window_set_transient_for (GTK_WINDOW (fsel), window);
-
-	g_object_set_data (G_OBJECT (fsel), "label", label);
-	g_object_set_data (G_OBJECT (fsel), "saved_flag", &saved_flag);
-
-	g_signal_connect (G_OBJECT (fsel->ok_button), "clicked",
-			  G_CALLBACK (save_as_ok_cb), fsel);
-
-	g_signal_connect (G_OBJECT (fsel->cancel_button), "clicked",
-			  G_CALLBACK (save_as_cancel_cb), fsel);
-
-	g_signal_connect (G_OBJECT (fsel), "destroy",
-			  G_CALLBACK (save_as_destroy_cb), &destroy_flag);
-
-	/* Recover proper state of save-as dialog */
-	if (save_path != NULL) {
-		gtk_file_selection_set_filename (fsel, save_path);
-	}
-
-	/* show the dialog */
-	gtk_widget_show (GTK_WIDGET (fsel));
-
-	/* Hold here and process events until we are done with this dialog. */
-	gtk_main ();
-
-	/* Destroy dialog if not already destroyed. */
-	if (!destroy_flag) {
-		/* Disconnect our destroy callback first, so that we don't
-		 * kill the current gtk_main() loop. */
-		g_signal_handlers_disconnect_by_func (GTK_OBJECT (fsel),
-						      G_CALLBACK (save_as_destroy_cb),
-						      &destroy_flag);
-		gtk_widget_destroy (GTK_WIDGET (fsel));
-	}
-
-	g_free (title);
-
-	gl_debug (DEBUG_FILE, "END");
-
-	/* Return flag as set by one of the above callbacks, TRUE = saved */
-	return saved_flag;
-}
-
-/*---------------------------------------------------------------------------*/
-/* PRIVATE.  "Save As" ok button callback.                                   */
-/*---------------------------------------------------------------------------*/
-static void
-save_as_ok_cb (GtkWidget        *widget,
-	       GtkFileSelection *fsel)
-{
-	gchar            *raw_filename, *filename, *full_filename;
-	GtkWidget        *dlg;
-	glLabel          *label;
-	glXMLLabelStatus  status;
-	EggRecentModel   *recent;
-	gboolean         *saved_flag;
-	gchar            *primary_msg;
-	gboolean          cancel_flag = FALSE;
-
-	gl_debug (DEBUG_FILE, "START");
-
-	g_return_if_fail (GTK_IS_FILE_SELECTION (fsel));
-
-	label = g_object_get_data (G_OBJECT(fsel), "label");
-	saved_flag = g_object_get_data (G_OBJECT(fsel), "saved_flag");
-
-	/* get the filename */
-	raw_filename = g_strdup (gtk_file_selection_get_filename (fsel));
-
-	gl_debug (DEBUG_FILE, "raw_filename = \"%s\"", raw_filename);
-
-	if (!raw_filename || g_file_test (raw_filename, G_FILE_TEST_IS_DIR)) {
-
-		dlg = gl_hig_alert_new (GTK_WINDOW(fsel),
-					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_MESSAGE_WARNING,
-					GTK_BUTTONS_CLOSE,
-					_("Empty file name selection"),
-					_("Please supply a valid file name"));
-
-		gtk_dialog_run (GTK_DIALOG (dlg));
-		gtk_widget_destroy (dlg);
-
-	} else {
-
-		full_filename = gl_util_add_extension (raw_filename);
-
-		filename = g_filename_to_utf8 (full_filename, -1, NULL, NULL, NULL);
-
-		gl_debug (DEBUG_FILE, "filename = \"%s\"", filename);
-
-		if (g_file_test (full_filename, G_FILE_TEST_IS_REGULAR)) {
-			gint ret;
-
-			primary_msg = g_strdup_printf (_("Overwrite file \"%s\"?"),
-						       filename);
-
-			dlg = gl_hig_alert_new (GTK_WINDOW(fsel),
-						GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-						GTK_MESSAGE_QUESTION,
-						GTK_BUTTONS_YES_NO,
-						primary_msg,
-						_("File already exists."));
-			
-			g_free (primary_msg);
-
-			ret = gtk_dialog_run (GTK_DIALOG (dlg));
-			if ( ret == GTK_RESPONSE_NO ) {
-				cancel_flag = TRUE;
-			}
-			gtk_widget_destroy (dlg);
-		}
-
-		if (!cancel_flag) {
-
-			gl_xml_label_save (label, filename, &status);
-
-			gl_debug (DEBUG_FILE, "status of save = %d", status);
-
-			if ( status != XML_LABEL_OK ) {
-
-				primary_msg = g_strdup_printf (_("Could not save file \"%s\""),
-							       filename);
-
-				dlg = gl_hig_alert_new (GTK_WINDOW(fsel),
-							GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-							GTK_MESSAGE_ERROR,
-							GTK_BUTTONS_CLOSE,
-							primary_msg,
-							_("Error encountered during save.  The file is still not saved."));
-
-				g_free (primary_msg);
-
-				gtk_dialog_run (GTK_DIALOG (dlg));
-				gtk_widget_destroy (dlg);
-
-			} else {
-
-				*saved_flag = TRUE;
-
-				gl_recent_add_uri (filename);
-
-				if (save_path != NULL)
-					g_free (save_path);
-				save_path = g_path_get_dirname (filename);
-				if (save_path != NULL)
-					save_path = g_strconcat (save_path, "/", NULL);
-
-				gtk_widget_destroy (GTK_WIDGET (fsel));
-			}
-
-		}
-
-		g_free (filename);
-		g_free (full_filename);
-	}
-
-	g_free (raw_filename);
-
-	gl_debug (DEBUG_FILE, "END");
-}
-
-/*---------------------------------------------------------------------------*/
-/* PRIVATE.  "Save As" cancel button callback.                               */
-/*---------------------------------------------------------------------------*/
-static void
-save_as_cancel_cb (GtkWidget        *widget,
-		   GtkFileSelection *fsel)
-{
-	gboolean *saved_flag = g_object_get_data (G_OBJECT (fsel), "saved_flag");
-
-	g_return_if_fail (GTK_IS_FILE_SELECTION (fsel));
-
-	*saved_flag = FALSE;
-	gtk_widget_hide (GTK_WIDGET (fsel));
-	gtk_main_quit ();
-}
-
-/*---------------------------------------------------------------------------*/
-/* PRIVATE.  "Save As" destroy callback.                                     */
-/*---------------------------------------------------------------------------*/
-static void
-save_as_destroy_cb (GtkWidget *widget,
-		    gboolean  *destroy_flag)
-{
-	*destroy_flag = TRUE;
-	gtk_main_quit ();
-}
-
-#endif
 
 /*****************************************************************************/
 /* "Close" menu callback.                                                    */
@@ -1261,49 +921,47 @@ gl_file_close (glWindow *window)
 		label = view->label;
 
 		if (gl_label_is_modified (label))	{
-			GtkWidget *msgbox, *w;
-			gchar *fname = NULL, *msg = NULL;
+			GtkWidget *dlg, *w;
+			gchar *fname = NULL;
 			gint ret;
 			gboolean exiting;
 
 			fname = gl_label_get_short_name (label);
 			
-			msg = g_strdup_printf (_("Save changes to document \"%s\" before closing?"),
-					       fname);
-			
-			msgbox = gl_hig_alert_new (GTK_WINDOW(window),
-						   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-						   GTK_MESSAGE_WARNING,
-						   GTK_BUTTONS_NONE,
-						   msg,
-						   _("Your changes will be lost if you don't save them."));
+			dlg = gtk_message_dialog_new (GTK_WINDOW(window),
+							 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+							 GTK_MESSAGE_WARNING,
+							 GTK_BUTTONS_NONE,
+							 _("Save changes to document \"%s\" before closing?"),
+							 fname);
+			gtk_message_dialog_format_secondary_text (
+				GTK_MESSAGE_DIALOG (dlg),
+				_("Your changes will be lost if you don't save them."));
 
-			gtk_dialog_add_button (GTK_DIALOG (msgbox),
+			gtk_dialog_add_button (GTK_DIALOG (dlg),
 					       _("Close without saving"),
 					       GTK_RESPONSE_NO);
 
-			gtk_dialog_add_button (GTK_DIALOG (msgbox),
+			gtk_dialog_add_button (GTK_DIALOG (dlg),
 					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 
-			gtk_dialog_add_button (GTK_DIALOG (msgbox),
+			gtk_dialog_add_button (GTK_DIALOG (dlg),
 					       GTK_STOCK_SAVE, GTK_RESPONSE_YES);
 
-			gtk_dialog_set_default_response	(GTK_DIALOG (msgbox), GTK_RESPONSE_YES);
+			gtk_dialog_set_default_response	(GTK_DIALOG (dlg), GTK_RESPONSE_YES);
 
-			gtk_window_set_resizable (GTK_WINDOW (msgbox), FALSE);
+			gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
 
-			ret = gtk_dialog_run (GTK_DIALOG (msgbox));
+			ret = gtk_dialog_run (GTK_DIALOG (dlg));
 		
-			gtk_widget_destroy (msgbox);
+			gtk_widget_destroy (dlg);
 
 			g_free (fname);
-			g_free (msg);
 		
 			switch (ret)
 			{
 			case GTK_RESPONSE_YES:
-				close = gl_file_save (label,
-						      GTK_WINDOW(window));
+				close = gl_file_save (label, window);
 				break;
 			case GTK_RESPONSE_NO:
 				close = TRUE;
@@ -1324,7 +982,7 @@ gl_file_close (glWindow *window)
 			
 			gl_debug (DEBUG_FILE, "All windows closed.");
 	
-			bonobo_main_quit ();
+			gtk_main_quit ();
 		}
 
 	}
