@@ -23,7 +23,9 @@
 #ifndef __HIG_H__
 #define __HIG_H__
 
-#include <gtk/gtk.h>
+#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtkvbox.h>
+#include <gtk/gtkhbox.h>
 
 G_BEGIN_DECLS
 
@@ -31,82 +33,6 @@ G_BEGIN_DECLS
 #define GL_HIG_PAD2  12
 
 
-/*===========================================================================*/
-/* HIG inspired alert.                                                       */
-/*===========================================================================*/
-
-#define GL_TYPE_HIG_ALERT (gl_hig_alert_get_type ())
-#define GL_HIG_ALERT(obj) \
-        (GTK_CHECK_CAST((obj), GL_TYPE_HIG_ALERT, glHigAlert ))
-#define GL_HIG_ALERT_CLASS(klass) \
-        (GTK_CHECK_CLASS_CAST ((klass), GL_TYPE_HIG_ALERT, glHigAlertClass))
-#define GL_IS_HIG_ALERT(obj) \
-        (GTK_CHECK_TYPE ((obj), GL_TYPE_HIG_ALERT))
-#define GL_IS_HIG_ALERT_CLASS(klass) \
-        (GTK_CHECK_CLASS_TYPE ((klass), GL_TYPE_HIG_ALERT))
-
-typedef struct _glHigAlert      glHigAlert;
-typedef struct _glHigAlertClass glHigAlertClass;
-
-struct _glHigAlert {
-	GtkDialog         parent_widget;
-};
-
-struct _glHigAlertClass {
-	GtkDialogClass    parent_class;
-};
-
-GType      gl_hig_alert_get_type    (void) G_GNUC_CONST;
-
-GtkWidget *gl_hig_alert_new         (GtkWindow      *parent,
-				     GtkDialogFlags  flags,
-				     GtkMessageType  type,
-				     GtkButtonsType  buttons,
-				     const gchar    *primary_text,
-				     const gchar    *secondary_text);
-
-
-/*===========================================================================*/
-/* HIG Dialog wrapper.                                                       */
-/*===========================================================================*/
-
-#define GL_TYPE_HIG_DIALOG (gl_hig_dialog_get_type ())
-#define GL_HIG_DIALOG(obj) \
-        (GTK_CHECK_CAST((obj), GL_TYPE_HIG_DIALOG, glHigDialog ))
-#define GL_HIG_DIALOG_CLASS(klass) \
-        (GTK_CHECK_CLASS_CAST ((klass), GL_TYPE_HIG_DIALOG, glHigDialogClass))
-#define GL_IS_HIG_DIALOG(obj) \
-        (GTK_CHECK_TYPE ((obj), GL_TYPE_HIG_DIALOG))
-#define GL_IS_HIG_DIALOG_CLASS(klass) \
-        (GTK_CHECK_CLASS_TYPE ((klass), GL_TYPE_HIG_DIALOG))
-
-typedef struct _glHigDialog      glHigDialog;
-typedef struct _glHigDialogClass glHigDialogClass;
-
-struct _glHigDialog {
-	GtkDialog         parent_widget;
-
-	GtkWidget        *vbox;
-};
-
-struct _glHigDialogClass {
-	GtkDialogClass    parent_class;
-};
-
-GType      gl_hig_dialog_get_type         (void) G_GNUC_CONST;
-
-GtkWidget *gl_hig_dialog_new              (void);
-
-GtkWidget *gl_hig_dialog_new_with_buttons (const gchar    *title,
-					   GtkWindow      *parent,
-					   GtkDialogFlags  flags,
-					   const gchar    *first_button_text,
-					   ...);
-
-void       gl_hig_dialog_add_widget       (glHigDialog   *dialog,
-					   GtkWidget     *widget);
-
-
 /*===========================================================================*/
 /* HIG Category (analogous to a gtk_frame).                                  */
 /*===========================================================================*/
