@@ -91,7 +91,44 @@ gl_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,DOUBLE (marshal.list:5) */
+/* VOID:INT,UINT (marshal.list:5) */
+void
+gl_marshal_VOID__INT_UINT (GClosure     *closure,
+                           GValue       *return_value,
+                           guint         n_param_values,
+                           const GValue *param_values,
+                           gpointer      invocation_hint,
+                           gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__INT_UINT) (gpointer     data1,
+                                               gint         arg_1,
+                                               guint        arg_2,
+                                               gpointer     data2);
+  register GMarshalFunc_VOID__INT_UINT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__INT_UINT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_int (param_values + 1),
+            g_marshal_value_peek_uint (param_values + 2),
+            data2);
+}
+
+/* VOID:INT,DOUBLE (marshal.list:6) */
 void
 gl_marshal_VOID__INT_DOUBLE (GClosure     *closure,
                              GValue       *return_value,
@@ -128,9 +165,9 @@ gl_marshal_VOID__INT_DOUBLE (GClosure     *closure,
             data2);
 }
 
-/* VOID:DOUBLE (marshal.list:6) */
+/* VOID:DOUBLE (marshal.list:7) */
 
-/* VOID:DOUBLE,DOUBLE (marshal.list:7) */
+/* VOID:DOUBLE,DOUBLE (marshal.list:8) */
 void
 gl_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
                                 GValue       *return_value,
@@ -167,9 +204,9 @@ gl_marshal_VOID__DOUBLE_DOUBLE (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING (marshal.list:8) */
+/* VOID:STRING (marshal.list:9) */
 
-/* BOOLEAN:OBJECT (marshal.list:9) */
+/* BOOLEAN:OBJECT (marshal.list:10) */
 void
 gl_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                             GValue       *return_value,
