@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
@@ -22,9 +24,9 @@
 #ifndef __MERGE_PROPERTIES_DIALOG_H__
 #define __MERGE_PROPERTIES_DIALOG_H__
 
-#include <gtk/gtk.h>
-#include "hig.h"
-#include "view.h"
+#include <gtk/gtkdialog.h>
+#include <gtk/gtkwindow.h>
+#include "label.h"
 
 G_BEGIN_DECLS
 
@@ -43,20 +45,21 @@ typedef struct _glMergePropertiesDialogPrivate  glMergePropertiesDialogPrivate;
 
 struct _glMergePropertiesDialog
 {
-	glHigDialog                     parent_instance;
+	GtkDialog                       parent_instance;
 
-	glMergePropertiesDialogPrivate *private;
+	glMergePropertiesDialogPrivate *priv;
 
 };
 
 struct  _glMergePropertiesDialogClass
 {
-	glHigDialogClass                parent_class;
+	GtkDialogClass                  parent_class;
 };
 
 GType      gl_merge_properties_dialog_get_type    (void) G_GNUC_CONST;
 
-GtkWidget *gl_merge_properties_dialog_new         (glView *view);
+GtkWidget *gl_merge_properties_dialog_new         (glLabel   *label,
+	                                           GtkWindow *window);
 
 G_END_DECLS
 
