@@ -21,10 +21,15 @@
  */
 #include <config.h>
 
-#include <gnome.h>
+#include "object-editor.h"
+
+#include <glib/gi18n.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtkcombobox.h>
+#include <gtk/gtktogglebutton.h>
 #include <math.h>
 
-#include "object-editor.h"
 #include "prefs.h"
 #include "mygal/widget-color-combo.h"
 #include "color.h"
@@ -49,7 +54,8 @@
 /* Local function prototypes                 */
 /*===========================================*/
 
-static void style_changed_cb (glObjectEditor       *editor);
+static void style_changed_cb     (glObjectEditor       *editor);
+static void bc_radio_toggled_cb  (glObjectEditor       *editor);
 
 
 /*--------------------------------------------------------------------------*/
@@ -65,8 +71,6 @@ gl_object_editor_prepare_bc_page (glObjectEditor       *editor)
 	/* Extract widgets from XML tree. */
 	editor->priv->bc_page_vbox =
 		glade_xml_get_widget (editor->priv->gui, "bc_page_vbox");
-	editor->priv->bc_style_entry =
-		glade_xml_get_widget (editor->priv->gui, "bc_style_entry");
 	editor->priv->bc_style_combo =
 		glade_xml_get_widget (editor->priv->gui, "bc_style_combo");
 	editor->priv->bc_text_check =
@@ -75,6 +79,12 @@ gl_object_editor_prepare_bc_page (glObjectEditor       *editor)
 		glade_xml_get_widget (editor->priv->gui, "bc_cs_check");
 	editor->priv->bc_color_combo =
 		glade_xml_get_widget (editor->priv->gui, "bc_color_combo");
+	editor->priv->bc_key_combo = 
+		glade_xml_get_widget (editor->priv->gui, "bc_key_combo");	
+	editor->priv->bc_key_radio = 
+		glade_xml_get_widget (editor->priv->gui, "bc_key_radio");	
+	editor->priv->bc_color_radio = 
+		glade_xml_get_widget (editor->priv->gui, "bc_color_radio");	
 	editor->priv->data_format_label =
 		glade_xml_get_widget (editor->priv->gui, "data_format_label");
 	editor->priv->data_ex_label =
@@ -86,16 +96,25 @@ gl_object_editor_prepare_bc_page (glObjectEditor       *editor)
 
 	editor->priv->data_format_fixed_flag = FALSE;
 
+	gl_util_combo_box_add_text_model ( GTK_COMBO_BOX(editor->priv->bc_style_combo));
+	gl_util_combo_box_add_text_model ( GTK_COMBO_BOX(editor->priv->bc_key_combo));
+
 	/* Load barcode styles */
 	styles = gl_barcode_get_styles_list ();
-	gtk_combo_set_popdown_strings (GTK_COMBO(editor->priv->bc_style_combo), styles);
+	gl_util_combo_box_set_strings (GTK_COMBO_BOX(editor->priv->bc_style_combo),
+				       styles);
 	gl_barcode_free_styles_list (styles);
 
+	/* Modify widgets */
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->bc_color_radio), TRUE);
+	gtk_widget_set_sensitive (editor->priv->bc_color_combo, TRUE);
+	gtk_widget_set_sensitive (editor->priv->bc_key_combo, FALSE);
+	
 	/* Un-hide */
 	gtk_widget_show_all (editor->priv->bc_page_vbox);
 
 	/* Connect signals */
-	g_signal_connect_swapped (G_OBJECT (editor->priv->bc_style_entry),
+	g_signal_connect_swapped (G_OBJECT (editor->priv->bc_style_combo),
 				  "changed",
 				  G_CALLBACK (style_changed_cb),
 				  G_OBJECT (editor));
@@ -111,6 +130,18 @@ gl_object_editor_prepare_bc_page (glObjectEditor       *editor)
 				  "color_changed",
 				  G_CALLBACK (gl_object_editor_changed_cb),
 				  G_OBJECT (editor));
+	g_signal_connect_swapped (G_OBJECT (editor->priv->bc_key_combo),
+				  "changed",
+				  G_CALLBACK (gl_object_editor_changed_cb),
+				  G_OBJECT (editor));
+	g_signal_connect_swapped (G_OBJECT (editor->priv->bc_color_radio),
+				  "toggled",
+				  G_CALLBACK (bc_radio_toggled_cb),
+				  G_OBJECT (editor));				  
+	g_signal_connect_swapped (G_OBJECT (editor->priv->bc_key_radio),
+				  "toggled",
+				  G_CALLBACK (bc_radio_toggled_cb),
+				  G_OBJECT (editor));
 	g_signal_connect_swapped (G_OBJECT (editor->priv->data_digits_spin),
 				  "changed",
 				  G_CALLBACK (gl_object_editor_changed_cb),
@@ -131,7 +162,7 @@ style_changed_cb (glObjectEditor       *editor)
 	guint           digits;
                                                                                 
         style_string =
-                gtk_editable_get_chars (GTK_EDITABLE(editor->priv->bc_style_entry), 0, -1);
+		gtk_combo_box_get_active_text (GTK_COMBO_BOX (editor->priv->bc_style_combo));
                                                                                 
         /* Don't emit if entry is empty. */
         if ( *style_string != 0 ) {
@@ -191,12 +222,11 @@ gl_object_editor_set_bc_style (glObjectEditor      *editor,
 			       guint                format_digits)
 {
 	const gchar *style_string;
-        gint         pos;
 	gchar       *ex_string;
  
 	gl_debug (DEBUG_EDITOR, "START");
 
-        g_signal_handlers_block_by_func (G_OBJECT(editor->priv->bc_style_entry),
+        g_signal_handlers_block_by_func (G_OBJECT(editor->priv->bc_style_combo),
                                          G_CALLBACK (style_changed_cb),
                                          editor);
         g_signal_handlers_block_by_func (G_OBJECT(editor->priv->bc_text_check),
@@ -211,14 +241,8 @@ gl_object_editor_set_bc_style (glObjectEditor      *editor,
 
         style_string = gl_barcode_id_to_name (id);
  
-        gtk_editable_delete_text (GTK_EDITABLE (editor->priv->bc_style_entry),
-                                  0, -1);
- 
-        pos = 0;
-        gtk_editable_insert_text (GTK_EDITABLE (editor->priv->bc_style_entry),
-                                  style_string,
-                                  strlen (style_string),
-                                  &pos);
+	gl_util_combo_box_set_active_text (GTK_COMBO_BOX (editor->priv->bc_style_combo),
+					   style_string);
  
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->bc_text_check),
                                       text_flag);
@@ -258,7 +282,7 @@ gl_object_editor_set_bc_style (glObjectEditor      *editor,
 					  !editor->priv->data_format_fixed_flag);
 	}
  
-        g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->bc_style_entry),
+        g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->bc_style_combo),
 					   G_CALLBACK (style_changed_cb),
 					   editor);
         g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->bc_text_check),
@@ -289,8 +313,7 @@ gl_object_editor_get_bc_style (glObjectEditor      *editor,
 	gl_debug (DEBUG_EDITOR, "START");
                                                                                 
         style_string =
-                gtk_editable_get_chars (GTK_EDITABLE(editor->priv->bc_style_entry),
-                                        0, -1);
+		gtk_combo_box_get_active_text (GTK_COMBO_BOX (editor->priv->bc_style_combo));
         *id = g_strdup (gl_barcode_name_to_id (style_string));
                                                                                 
         *text_flag =
@@ -313,7 +336,8 @@ gl_object_editor_get_bc_style (glObjectEditor      *editor,
 /*****************************************************************************/
 void
 gl_object_editor_set_bc_color (glObjectEditor      *editor,
-			       guint                bc_color)
+			       gboolean             merge_flag,
+			       glColorNode         *color_node)
 {
 	GdkColor *gdk_color;
 
@@ -322,43 +346,106 @@ gl_object_editor_set_bc_color (glObjectEditor      *editor,
 	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->bc_color_combo),
 					 gl_object_editor_changed_cb,
 					 editor);
+	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->bc_key_combo),
+					 gl_object_editor_changed_cb,
+					 editor);
 
-        gdk_color = gl_color_to_gdk_color (bc_color);
-        color_combo_set_color (COLOR_COMBO(editor->priv->bc_color_combo), gdk_color);
-        g_free (gdk_color);
+	gtk_widget_set_sensitive (editor->priv->bc_key_radio, merge_flag);
 
+	if ( color_node->color == GL_COLOR_NONE ) {
+
+		color_combo_set_color_to_default (COLOR_COMBO(editor->priv->bc_color_combo));
+
+	} else {
+
+		gdk_color = gl_color_to_gdk_color (color_node->color);
+		color_combo_set_color (COLOR_COMBO(editor->priv->bc_color_combo),
+					   gdk_color);
+		g_free (gdk_color);
+	}
+	
+	if (!color_node->field_flag) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+						  (editor->priv->bc_color_radio), TRUE); 
+		gtk_widget_set_sensitive (editor->priv->bc_color_combo, TRUE);
+		gtk_widget_set_sensitive (editor->priv->bc_key_combo, FALSE);
+		
+	} else {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+						  (editor->priv->bc_key_radio), TRUE); 
+		gtk_widget_set_sensitive (editor->priv->bc_color_combo, FALSE);
+		gtk_widget_set_sensitive (editor->priv->bc_key_combo, TRUE);
+		
+		gl_util_combo_box_set_active_text (GTK_COMBO_BOX (editor->priv->bc_key_combo),
+						   color_node->key);
+	}	
+	
 	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->bc_color_combo),
 					   gl_object_editor_changed_cb,
 					   editor);
-
+	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->bc_key_combo),
+					   gl_object_editor_changed_cb,
+					   editor);
+	
 	gl_debug (DEBUG_EDITOR, "END");
 }
 
 /*****************************************************************************/
 /* Query bc color.                                                           */
 /*****************************************************************************/
-guint
+glColorNode*
 gl_object_editor_get_bc_color (glObjectEditor      *editor)
 {
-	GdkColor  *gdk_color;
-	guint     color;
-	gboolean  is_default;
+	GdkColor     *gdk_color;
+	glColorNode  *color_node;
+	gboolean      is_default;
 
 	gl_debug (DEBUG_EDITOR, "START");
 
-        gdk_color = color_combo_get_color (COLOR_COMBO(editor->priv->bc_color_combo),
+	color_node = gl_color_node_new_default ();
+	
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (editor->priv->bc_key_radio))) {
+		color_node->field_flag = TRUE;
+		color_node->color = gl_prefs->default_line_color;
+		color_node->key = 
+			gtk_combo_box_get_active_text (GTK_COMBO_BOX (editor->priv->bc_key_combo));
+	} else {
+		color_node->field_flag = FALSE;
+		color_node->key = NULL;
+		gdk_color = color_combo_get_color (COLOR_COMBO(editor->priv->bc_color_combo),
                                            &is_default);
-                                                                                
-        if (is_default) {
-                color = gl_prefs->default_line_color;
-        } else {
-                color = gl_color_from_gdk_color (gdk_color);
-        }
-                                                                                
 
+		if (is_default) {
+			color_node->color = gl_prefs->default_line_color;
+		} else {
+			color_node->color = gl_color_from_gdk_color (gdk_color);
+		}
+	}
+	
 	gl_debug (DEBUG_EDITOR, "END");
 
-	return color;
+	return color_node;
 }
 
-
+/*--------------------------------------------------------------------------*/
+/* PRIVATE.  barcode color radio callback.                                  */
+/*--------------------------------------------------------------------------*/
+static void
+bc_radio_toggled_cb (glObjectEditor *editor)
+{
+    gl_debug (DEBUG_EDITOR, "START");
+	
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (editor->priv->bc_color_radio))) {
+                gtk_widget_set_sensitive (editor->priv->bc_color_combo, TRUE);
+                gtk_widget_set_sensitive (editor->priv->bc_key_combo, FALSE);
+    } else {
+                gtk_widget_set_sensitive (editor->priv->bc_color_combo, FALSE);
+                gtk_widget_set_sensitive (editor->priv->bc_key_combo, TRUE);
+		
+	}
+ 
+    /* Emit our "changed" signal */
+    g_signal_emit (G_OBJECT (editor), gl_object_editor_signals[CHANGED], 0);
+ 
+    gl_debug (DEBUG_EDITOR, "END");
+}
