@@ -21,10 +21,13 @@
  */
 #include <config.h>
 
-#include <gnome.h>
+#include "object-editor.h"
+
+#include <glib/gi18n.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkspinbutton.h>
 #include <math.h>
 
-#include "object-editor.h"
 #include "prefs.h"
 #include "wdgt-chain-button.h"
 
