@@ -21,10 +21,14 @@
  */
 #include <config.h>
 
-#include <gnome.h>
+#include "object-editor.h"
+
+#include <glib/gi18n.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtkcombobox.h>
 #include <math.h>
 
-#include "object-editor.h"
 #include "prefs.h"
 #include "mygal/widget-color-combo.h"
 #include "color.h"
@@ -51,6 +55,7 @@
 
 static void align_toggle_cb (GtkToggleButton *toggle,
 			     glObjectEditor  *editor);
+static void text_radio_toggled_cb              (glObjectEditor        *editor);
 
 
 /*--------------------------------------------------------------------------*/
@@ -66,8 +71,6 @@ gl_object_editor_prepare_text_page (glObjectEditor       *editor)
 	/* Extract widgets from XML tree. */
 	editor->priv->text_page_vbox =
 		glade_xml_get_widget (editor->priv->gui, "text_page_vbox");
-	editor->priv->text_family_entry =
-		glade_xml_get_widget (editor->priv->gui, "text_family_entry");
 	editor->priv->text_family_combo =
 		glade_xml_get_widget (editor->priv->gui, "text_family_combo");
 	editor->priv->text_size_spin =
@@ -78,6 +81,12 @@ gl_object_editor_prepare_text_page (glObjectEditor       *editor)
 		glade_xml_get_widget (editor->priv->gui, "text_italic_toggle");
 	editor->priv->text_color_combo =
 		glade_xml_get_widget (editor->priv->gui, "text_color_combo");
+	editor->priv->text_color_radio =
+		glade_xml_get_widget (editor->priv->gui, "text_color_radio");
+	editor->priv->text_color_key_radio =
+		glade_xml_get_widget (editor->priv->gui, "text_color_key_radio");
+	editor->priv->text_color_key_combo =
+		glade_xml_get_widget (editor->priv->gui, "text_color_key_combo");
 	editor->priv->text_left_toggle =
 		glade_xml_get_widget (editor->priv->gui, "text_left_toggle");
 	editor->priv->text_center_toggle =
@@ -89,17 +98,25 @@ gl_object_editor_prepare_text_page (glObjectEditor       *editor)
 	editor->priv->text_auto_shrink_check =
 		glade_xml_get_widget (editor->priv->gui, "text_auto_shrink_check");
 
+	gl_util_combo_box_add_text_model ( GTK_COMBO_BOX(editor->priv->text_family_combo));
+	gl_util_combo_box_add_text_model ( GTK_COMBO_BOX(editor->priv->text_color_key_combo));
+
 	/* Load family names */
 	family_names = gnome_font_family_list ();
-	gtk_combo_set_popdown_strings (GTK_COMBO(editor->priv->text_family_combo),
+	gl_util_combo_box_set_strings (GTK_COMBO_BOX(editor->priv->text_family_combo),
 				       family_names);
 	gnome_font_family_list_free (family_names);
 
+	/* Modify widgets */
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->text_color_radio), TRUE);
+	gtk_widget_set_sensitive (editor->priv->text_color_combo, TRUE);
+    gtk_widget_set_sensitive (editor->priv->text_color_key_combo, FALSE);
+
 	/* Un-hide */
 	gtk_widget_show_all (editor->priv->text_page_vbox);
 
 	/* Connect signals */
-	g_signal_connect_swapped (G_OBJECT (editor->priv->text_family_entry),
+	g_signal_connect_swapped (G_OBJECT (editor->priv->text_family_combo),
 				  "changed",
 				  G_CALLBACK (gl_object_editor_changed_cb),
 				  G_OBJECT (editor));
@@ -119,6 +136,18 @@ gl_object_editor_prepare_text_page (glObjectEditor       *editor)
 				  "color_changed",
 				  G_CALLBACK (gl_object_editor_changed_cb),
 				  G_OBJECT (editor));
+	g_signal_connect_swapped (G_OBJECT (editor->priv->text_color_key_combo),
+				  "changed",
+				  G_CALLBACK (gl_object_editor_changed_cb),
+				  G_OBJECT (editor));
+	g_signal_connect_swapped (G_OBJECT (editor->priv->text_color_radio),
+				  "toggled",
+				  G_CALLBACK (text_radio_toggled_cb),
+				  G_OBJECT (editor));				  
+	g_signal_connect_swapped (G_OBJECT (editor->priv->text_color_key_radio),
+				  "toggled",
+				  G_CALLBACK (text_radio_toggled_cb),
+				  G_OBJECT (editor));
 
 	g_signal_connect (G_OBJECT (editor->priv->text_left_toggle),
 			  "toggled",
@@ -198,7 +227,7 @@ gl_object_editor_set_font_family (glObjectEditor      *editor,
 
 	gl_debug (DEBUG_EDITOR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_family_entry),
+	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_family_combo),
 					 gl_object_editor_changed_cb,
 					 editor);
 
@@ -214,10 +243,10 @@ gl_object_editor_set_font_family (glObjectEditor      *editor,
                 }
         }
         gnome_font_family_list_free (family_names);
-        gtk_entry_set_text (GTK_ENTRY (editor->priv->text_family_entry), good_font_family);
+        gl_util_combo_box_set_active_text (GTK_COMBO_BOX (editor->priv->text_family_combo), good_font_family);
         g_free (good_font_family);
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_family_entry),
+	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_family_combo),
 					   gl_object_editor_changed_cb,
 					   editor);
 
@@ -234,9 +263,7 @@ gl_object_editor_get_font_family (glObjectEditor      *editor)
 
 	gl_debug (DEBUG_EDITOR, "START");
 
-	font_family =
-		gtk_editable_get_chars (GTK_EDITABLE (editor->priv->text_family_entry),
-					0, -1);
+	font_family = gtk_combo_box_get_active_text (GTK_COMBO_BOX (editor->priv->text_family_combo));
 
 	gl_debug (DEBUG_EDITOR, "END");
 
@@ -446,23 +473,60 @@ gl_object_editor_get_text_alignment (glObjectEditor      *editor)
 /*****************************************************************************/
 void
 gl_object_editor_set_text_color (glObjectEditor      *editor,
-				 guint                text_color)
+				 gboolean             merge_flag,
+				 glColorNode         *text_color_node)
 {
 	GdkColor *gdk_color;
+	gint pos;
 
 	gl_debug (DEBUG_EDITOR, "START");
 
 	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_color_combo),
 					 gl_object_editor_changed_cb,
 					 editor);
+	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_color_key_combo),
+					 gl_object_editor_changed_cb,
+					 editor);
 
-        gdk_color = gl_color_to_gdk_color (text_color);
+	gl_debug (DEBUG_EDITOR, "color field %s(%d) / %X", text_color_node->key, text_color_node->field_flag, text_color_node->color);
+	
+	gtk_widget_set_sensitive (editor->priv->text_color_key_radio, merge_flag);
+
+	if ( text_color_node->color == GL_COLOR_NONE ) {
+
+		color_combo_set_color_to_default (COLOR_COMBO(editor->priv->text_color_combo));
+
+	} else {
+		
+        gdk_color = gl_color_to_gdk_color (text_color_node->color);
         color_combo_set_color (COLOR_COMBO(editor->priv->text_color_combo), gdk_color);
         g_free (gdk_color);
+	}
+	
+	if (!text_color_node->field_flag) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+						  (editor->priv->text_color_radio), TRUE); 
+		gtk_widget_set_sensitive (editor->priv->text_color_combo, TRUE);
+		gl_debug (DEBUG_EDITOR, "color field false 0");
+		gtk_widget_set_sensitive (editor->priv->text_color_key_combo, FALSE);
+		
+	} else {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+						  (editor->priv->text_color_key_radio), TRUE); 
+		gtk_widget_set_sensitive (editor->priv->text_color_combo, FALSE);
+		gtk_widget_set_sensitive (editor->priv->text_color_key_combo, TRUE);
+		
+		gl_debug (DEBUG_EDITOR, "color field true 1");
+		gl_util_combo_box_set_active_text (GTK_COMBO_BOX (editor->priv->text_color_key_combo));
+		gl_debug (DEBUG_EDITOR, "color field true 2");
+	}
 
 	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_color_combo),
 					   gl_object_editor_changed_cb,
 					   editor);
+	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_color_key_combo),
+					   gl_object_editor_changed_cb,
+					   editor);
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -470,28 +534,38 @@ gl_object_editor_set_text_color (glObjectEditor      *editor,
 /*****************************************************************************/
 /* Query text color.                                                         */
 /*****************************************************************************/
-guint
+glColorNode*
 gl_object_editor_get_text_color (glObjectEditor      *editor)
 {
-	GdkColor  *gdk_color;
-	guint     color;
-	gboolean  is_default;
+	GdkColor    *gdk_color;
+	glColorNode *color_node;
+	gboolean     is_default;
 
 	gl_debug (DEBUG_EDITOR, "START");
 
-        gdk_color = color_combo_get_color (COLOR_COMBO(editor->priv->text_color_combo),
+	color_node = gl_color_node_new_default ();
+	
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (editor->priv->text_color_key_radio))) {
+		color_node->field_flag = TRUE;
+		color_node->color = gl_prefs->default_text_color;
+		color_node->key = 
+			gtk_combo_box_get_active_text (GTK_COMBO_BOX (editor->priv->text_color_key_combo));
+    } else {
+		color_node->field_flag = FALSE;
+		color_node->key = NULL;
+		gdk_color = color_combo_get_color (COLOR_COMBO(editor->priv->text_color_combo),
                                            &is_default);
-                                                                                
+
         if (is_default) {
-                color = gl_prefs->default_text_color;
+                color_node->color = gl_prefs->default_text_color;
         } else {
-                color = gl_color_from_gdk_color (gdk_color);
+                color_node->color = gl_color_from_gdk_color (gdk_color);
         }
-                                                                                
+	}      
 
 	gl_debug (DEBUG_EDITOR, "END");
 
-	return color;
+	return color_node;
 }
 
 
@@ -576,3 +650,25 @@ gboolean    gl_object_editor_get_text_auto_shrink (glObjectEditor      *editor)
 	return auto_shrink;
 }
 
+/*--------------------------------------------------------------------------*/
+/* PRIVATE.  color radio callback.                                           */
+/*--------------------------------------------------------------------------*/
+static void
+text_radio_toggled_cb (glObjectEditor *editor)
+{
+    gl_debug (DEBUG_EDITOR, "START");
+	
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (editor->priv->text_color_radio))) {
+                gtk_widget_set_sensitive (editor->priv->text_color_combo, TRUE);
+                gtk_widget_set_sensitive (editor->priv->text_color_key_combo, FALSE);
+    } else {
+                gtk_widget_set_sensitive (editor->priv->text_color_combo, FALSE);
+                gtk_widget_set_sensitive (editor->priv->text_color_key_combo, TRUE);
+		
+	}
+ 
+        /* Emit our "changed" signal */
+        g_signal_emit (G_OBJECT (editor), gl_object_editor_signals[CHANGED], 0);
+ 
+        gl_debug (DEBUG_EDITOR, "END");
+}
