@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
@@ -21,14 +23,22 @@
  */
 #include <config.h>
 
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
-#include <glade/glade-xml.h>
-
 #include "prefs-dialog.h"
+
+#include <glib/gi18n.h>
+#include <libgnomeprint/gnome-font.h>
+#include <glade/glade-xml.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtkcombobox.h>
+#include <gtk/gtkspinbutton.h>
+
 #include "prefs.h"
+#include "hig.h"
 #include "mygal/widget-color-combo.h"
 #include "color.h"
+#include "util.h"
+
 #include "debug.h"
 
 /*========================================================*/
@@ -56,7 +66,6 @@ struct _glPrefsDialogPrivate
 	GtkWidget	*page_size_a4_radio;
 
 	/* Default text properties */
-	GtkWidget       *text_family_entry;
 	GtkWidget       *text_family_combo;
 	GtkWidget       *text_size_spin;
 	GtkWidget       *text_bold_toggle;
@@ -79,7 +88,7 @@ struct _glPrefsDialogPrivate
 /* Private globals.                                       */
 /*========================================================*/
 
-static glHigDialogClass* parent_class = NULL;
+static GtkDialogClass* parent_class = NULL;
 
 /*========================================================*/
 /* Private function prototypes.                           */
@@ -131,7 +140,7 @@ gl_prefs_dialog_get_type (void)
 			NULL
       		};
 
-     		type = g_type_register_static (GL_TYPE_HIG_DIALOG,
+     		type = g_type_register_static (GTK_TYPE_DIALOG,
 					       "glPrefsDialog", &info, 0);
     	}
 
@@ -162,10 +171,23 @@ gl_prefs_dialog_init (glPrefsDialog *dlg)
 					NULL);
 
 	if (!dlg->priv->gui) {
-		g_warning ("Could not open prefs-dialog.glade, reinstall glabels!");
+		g_critical ("Could not open prefs-dialog.glade. gLabels may not be installed correctly!");
 		return;
 	}
 
+	gtk_container_set_border_width (GTK_CONTAINER(dlg), GL_HIG_PAD2);
+
+	gtk_dialog_set_has_separator (GTK_DIALOG(dlg), FALSE);
+	gtk_dialog_add_button (GTK_DIALOG(dlg), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+	gtk_dialog_set_default_response (GTK_DIALOG (dlg), GTK_RESPONSE_CLOSE);
+
+	g_signal_connect(G_OBJECT (dlg), "response",
+			 G_CALLBACK (response_cb), NULL);
+
+        gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
+        gtk_window_set_title (GTK_WINDOW (dlg), _("gLabels Preferences"));
+        gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
+
 	gl_debug (DEBUG_PREFS, "END");
 }
 
@@ -225,16 +247,8 @@ gl_prefs_dialog_construct (glPrefsDialog *dlg)
 	g_return_if_fail (GL_IS_PREFS_DIALOG (dlg));
 	g_return_if_fail (dlg->priv != NULL);
 
-	gtk_dialog_add_button (GTK_DIALOG(dlg),
-			       GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
-
-	gtk_dialog_set_default_response (GTK_DIALOG (dlg), GTK_RESPONSE_CLOSE);
-
-	g_signal_connect(G_OBJECT (dlg), "response",
-			 G_CALLBACK (response_cb), NULL);
-
 	notebook = glade_xml_get_widget (dlg->priv->gui, "prefs_notebook");
-	gl_hig_dialog_add_widget (GL_HIG_DIALOG(dlg), notebook);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), notebook, FALSE, FALSE, 0);
 
 	construct_locale_page (dlg);
 	construct_object_page (dlg);
@@ -243,10 +257,6 @@ gl_prefs_dialog_construct (glPrefsDialog *dlg)
 	update_object_page_from_prefs (dlg);
 
         gtk_widget_show_all (GTK_DIALOG (dlg)->vbox);   
-
-        gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
-        gtk_window_set_title (GTK_WINDOW (dlg), _("gLabels Preferences"));
-        gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
 }
 
 /*---------------------------------------------------------------------------*/
@@ -323,8 +333,6 @@ construct_object_page (glPrefsDialog *dlg)
 {
         GList    *family_names;
 
-	dlg->priv->text_family_entry =
-		glade_xml_get_widget (dlg->priv->gui, "text_family_entry");
 	dlg->priv->text_family_combo =
 		glade_xml_get_widget (dlg->priv->gui, "text_family_combo");
 	dlg->priv->text_size_spin =
@@ -352,14 +360,16 @@ construct_object_page (glPrefsDialog *dlg)
 	dlg->priv->fill_color_combo =
 		glade_xml_get_widget (dlg->priv->gui, "fill_color_combo");
 
+	gl_util_combo_box_add_text_model (GTK_COMBO_BOX (dlg->priv->text_family_combo));
+
         /* Load family names */
         family_names = gnome_font_family_list ();
-        gtk_combo_set_popdown_strings (GTK_COMBO(dlg->priv->text_family_combo),
+	gl_util_combo_box_set_strings (GTK_COMBO_BOX (dlg->priv->text_family_combo),
 				       family_names);
         gnome_font_family_list_free (family_names);
                                                                                 
 
-	g_signal_connect_swapped (G_OBJECT(dlg->priv->text_family_entry),
+	g_signal_connect_swapped (G_OBJECT(dlg->priv->text_family_combo),
 				  "changed",
 				  G_CALLBACK(update_prefs_from_object_page),
 				  G_OBJECT(dlg));
@@ -477,12 +487,12 @@ update_locale_page_from_prefs (glPrefsDialog *dlg)
 		G_CALLBACK(update_prefs_from_locale_page), G_OBJECT(dlg));
 
 	switch (gl_prefs->units) {
-	case GL_UNITS_PTS:
+	case GL_UNITS_POINT:
 		gtk_toggle_button_set_active (
 			GTK_TOGGLE_BUTTON(dlg->priv->units_points_radio),
 			TRUE);
 		break;
-	case GL_UNITS_INCHES:
+	case GL_UNITS_INCH:
 		gtk_toggle_button_set_active (
 			GTK_TOGGLE_BUTTON(dlg->priv->units_inches_radio),
 			TRUE);
@@ -493,7 +503,7 @@ update_locale_page_from_prefs (glPrefsDialog *dlg)
 			TRUE);
 		break;
 	default:
-		g_warning ("Illegal units");	/* Should not happen */
+		g_message ("Illegal units");	/* Should not happen */
 		break;
 	}
 
@@ -506,7 +516,7 @@ update_locale_page_from_prefs (glPrefsDialog *dlg)
 			GTK_TOGGLE_BUTTON(dlg->priv->page_size_a4_radio),
 			TRUE);
 	} else {
-		g_warning ("Unknown default page size"); /* Shouldn't happen */
+		g_message ("Unknown default page size"); /* Shouldn't happen */
 	}
 
 	g_signal_handlers_unblock_by_func (
@@ -537,7 +547,7 @@ update_object_page_from_prefs (glPrefsDialog *dlg)
 	GdkColor *gdk_color;
  
 	g_signal_handlers_block_by_func (
-		G_OBJECT(dlg->priv->text_family_entry),
+		G_OBJECT(dlg->priv->text_family_combo),
 		G_CALLBACK(update_prefs_from_object_page), G_OBJECT(dlg));
 	g_signal_handlers_block_by_func (
 		G_OBJECT(dlg->priv->text_size_spin),
@@ -588,7 +598,8 @@ update_object_page_from_prefs (glPrefsDialog *dlg)
                 }
         }
         gnome_font_family_list_free (family_names);
-        gtk_entry_set_text (GTK_ENTRY (dlg->priv->text_family_entry), good_font_family);
+	gl_util_combo_box_set_active_text (GTK_COMBO_BOX (dlg->priv->text_family_combo),
+					   good_font_family);
         g_free (good_font_family);
 
         gtk_spin_button_set_value (GTK_SPIN_BUTTON (dlg->priv->text_size_spin),
@@ -628,7 +639,7 @@ update_object_page_from_prefs (glPrefsDialog *dlg)
 
 
 	g_signal_handlers_unblock_by_func (
-		G_OBJECT(dlg->priv->text_family_entry),
+		G_OBJECT(dlg->priv->text_family_combo),
 		G_CALLBACK(update_prefs_from_object_page), G_OBJECT(dlg));
 	g_signal_handlers_unblock_by_func (
 		G_OBJECT(dlg->priv->text_size_spin),
@@ -673,11 +684,11 @@ update_prefs_from_locale_page (glPrefsDialog *dlg)
 {
 	if (gtk_toggle_button_get_active (
 		    GTK_TOGGLE_BUTTON(dlg->priv->units_points_radio))) {
-		gl_prefs->units = GL_UNITS_PTS;
+		gl_prefs->units = GL_UNITS_POINT;
 	}
 	if (gtk_toggle_button_get_active (
 		    GTK_TOGGLE_BUTTON(dlg->priv->units_inches_radio))) {
-		gl_prefs->units = GL_UNITS_INCHES;
+		gl_prefs->units = GL_UNITS_INCH;
 	}
 	if (gtk_toggle_button_get_active (
 		    GTK_TOGGLE_BUTTON(dlg->priv->units_mm_radio))) {
@@ -708,8 +719,7 @@ update_prefs_from_object_page (glPrefsDialog *dlg)
 
         g_free (gl_prefs->default_font_family);
         gl_prefs->default_font_family =
-                gtk_editable_get_chars (GTK_EDITABLE (dlg->priv->text_family_entry),
-					0, -1);
+		gtk_combo_box_get_active_text (GTK_COMBO_BOX (dlg->priv->text_family_combo));
         gl_prefs->default_font_size =
                 gtk_spin_button_get_value (GTK_SPIN_BUTTON(dlg->priv->text_size_spin));
 
