@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
@@ -21,15 +23,18 @@
  */
 #include <config.h>
 
+#include "print-dialog.h"
+
+#include <glib/gi18n.h>
 #include <math.h>
 #include <time.h>
 #include <ctype.h>
-#include <gtk/gtk.h>
+#include <gtk/gtkdialog.h>
+#include <gtk/gtknotebook.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
 #include <libgnomeprint/gnome-print-job.h>
 #include <libgnomeprintui/gnome-print-job-preview.h>
 
-#include "print-dialog.h"
 #include "print.h"
 #include "label.h"
 
@@ -73,7 +78,7 @@ struct _glPrintDialogPrivate {
 /* Private globals                           */
 /*===========================================*/
 
-static glHigDialogClass* parent_class = NULL;
+static GtkDialogClass* parent_class = NULL;
 
 /*===========================================*/
 /* Local function prototypes                 */
@@ -85,7 +90,7 @@ static void       gl_print_dialog_finalize        (GObject            *object);
 
 static void       gl_print_dialog_construct       (glPrintDialog      *dialog,
 						   glLabel            *label,
-						   BonoboWindow       *win);
+						   GtkWindow          *win);
 
 static GtkWidget *job_page_new                    (glPrintDialog      *dialog,
 						   glLabel            *label);
@@ -153,7 +158,7 @@ gl_print_dialog_get_type (void)
 			NULL
       		};
 
-     		type = g_type_register_static (GL_TYPE_HIG_DIALOG,
+     		type = g_type_register_static (GTK_TYPE_DIALOG,
 					       "glPrintDialog", &info, 0);
     	}
 
@@ -181,6 +186,9 @@ gl_print_dialog_init (glPrintDialog *dialog)
 
 	dialog->priv = g_new0 (glPrintDialogPrivate, 1);
 
+	gtk_container_set_border_width (GTK_CONTAINER(dialog), GL_HIG_PAD2);
+
+	gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
 	gtk_dialog_add_buttons (GTK_DIALOG(dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_PRINT,  GNOME_PRINT_DIALOG_RESPONSE_PRINT,
@@ -232,7 +240,7 @@ gl_print_dialog_finalize (GObject *object)
 /*****************************************************************************/
 GtkWidget *
 gl_print_dialog_new (glLabel      *label,
-		     BonoboWindow *win)
+		     GtkWindow    *win)
 {
 	GtkWidget *dialog;
 
@@ -251,7 +259,7 @@ gl_print_dialog_new (glLabel      *label,
 static void
 gl_print_dialog_construct (glPrintDialog      *dialog,
 			   glLabel            *label,
-			   BonoboWindow       *win)
+			   GtkWindow          *win)
 {
 	GtkWidget *notebook, *page;
 	gchar     *name, *title;
@@ -273,7 +281,7 @@ gl_print_dialog_construct (glPrintDialog      *dialog,
 	}
 
 	notebook = gtk_notebook_new ();
-	gl_hig_dialog_add_widget (GL_HIG_DIALOG(dialog), notebook);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), notebook, FALSE, FALSE, 0);
 
 	/* ----- Create Job notebook page ----- */
 	page = job_page_new (dialog, label);
@@ -378,7 +386,7 @@ printer_page_new (glPrintDialog *dialog,
 	dialog->priv->printer_select =
 		gnome_printer_selector_new (gnome_print_config_default ());
 	gtk_widget_show (dialog->priv->printer_select);
-	gl_hig_vbox_add_widget (GL_HIG_VBOX(vbox), dialog->priv->printer_select);
+	gtk_box_pack_start (GTK_BOX(vbox), dialog->priv->printer_select, TRUE, TRUE, 0);
 
 	return vbox;
 }
@@ -550,7 +558,7 @@ print_sheets (GnomePrintConfig *config,
 
 	if (preview_flag) {
 		GtkWidget *preview_widget =
-		    gnome_print_job_preview_new (job, _("Print preview"));
+		    gnome_print_job_preview_new (job, (guchar *)_("Print preview"));
 		gtk_widget_show (GTK_WIDGET (preview_widget));
 	} else {
 		gnome_print_job_print (job);
@@ -589,7 +597,7 @@ print_sheets_merge (GnomePrintConfig *config,
 
 	if (preview_flag) {
 	        GtkWidget *preview_widget =
-		    gnome_print_job_preview_new (job, _("Print preview"));
+		    gnome_print_job_preview_new (job, (guchar *)_("Print preview"));
 		gtk_widget_show (GTK_WIDGET (preview_widget));
 	} else {
 		gnome_print_job_print (job);
