@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
@@ -22,9 +24,8 @@
 #ifndef __PRINT_DIALOG_H__
 #define __PRINT_DIALOG_H__
 
-#include <gtk/gtk.h>
-#include <bonobo/bonobo-window.h>
-#include "hig.h"
+#include <gtk/gtkwindow.h>
+#include <gtk/gtkdialog.h>
 #include "view.h"
 
 G_BEGIN_DECLS
@@ -44,7 +45,7 @@ typedef struct _glPrintDialogPrivate  glPrintDialogPrivate;
 
 struct _glPrintDialog
 {
-	glHigDialog           parent_instance;
+	GtkDialog             parent_instance;
 
 	glPrintDialogPrivate *priv;
 
@@ -52,14 +53,14 @@ struct _glPrintDialog
 
 struct  _glPrintDialogClass
 {
-	glHigDialogClass      parent_class;
+	GtkDialogClass        parent_class;
 };
 
 
 GType      gl_print_dialog_get_type            (void) G_GNUC_CONST;
 
 GtkWidget *gl_print_dialog_new                 (glLabel       *label,
-						BonoboWindow  *win);
+						GtkWindow     *win);
 
 void       gl_print_dialog_force_outline_flag  (glPrintDialog *dialog);
 
