@@ -1,9 +1,11 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
  *  print.c:  Print module
  *
- *  Copyright (C) 2001  Jim Evins <evins@snaught.com>.
+ *  Copyright (C) 2001-2006  Jim Evins <evins@snaught.com>.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -111,15 +113,15 @@ static void       draw_text_object            (PrintInfo        *pi,
 
 static void       draw_box_object             (PrintInfo        *pi,
 					       glLabelBox       *object,
-						   glMergeRecord  *record);
+					       glMergeRecord    *record);
 
 static void       draw_line_object            (PrintInfo        *pi,
 					       glLabelLine      *object,
-						   glMergeRecord  *record);						   
+					       glMergeRecord    *record);						   
 
 static void       draw_ellipse_object         (PrintInfo        *pi,
 					       glLabelEllipse   *object,
-						   glMergeRecord  *record);
+					       glMergeRecord    *record);
 
 static void       draw_image_object           (PrintInfo        *pi,
 					       glLabelImage     *object,
@@ -745,6 +747,11 @@ draw_text_object (PrintInfo     *pi,
 	ArtDRect         bbox;
 	gdouble          affine[6];
 	gdouble          text_line_spacing;
+	gboolean         shadow_state;
+	gdouble          shadow_x, shadow_y;
+	glColorNode     *shadow_color_node;
+	gdouble          shadow_opacity;
+	guint            shadow_color;
 
 
 	gl_debug (DEBUG_PRINT, "START");
@@ -765,6 +772,17 @@ draw_text_object (PrintInfo     *pi,
 		gl_label_object_get_text_line_spacing (GL_LABEL_OBJECT(object));
 	auto_shrink = gl_label_text_get_auto_shrink (object);
 
+	shadow_state = gl_label_object_get_shadow_state (GL_LABEL_OBJECT (object));
+	gl_label_object_get_shadow_offset (GL_LABEL_OBJECT (object), &shadow_x, &shadow_y);
+	shadow_color_node = gl_label_object_get_shadow_color (GL_LABEL_OBJECT (object));
+	if (shadow_color_node->field_flag)
+	{
+		shadow_color_node->color = GL_COLOR_SHADOW_MERGE_DEFAULT;
+	}
+	shadow_opacity = gl_label_object_get_shadow_opacity (GL_LABEL_OBJECT (object));
+	shadow_color = gl_color_shadow (shadow_color_node->color, shadow_opacity, color);
+	gl_color_node_free (&shadow_color_node);
+
 	text = gl_text_node_lines_expand (lines, record);
 	line = g_strsplit (text, "\n", -1);
 	g_free (text);
@@ -821,6 +839,59 @@ draw_text_object (PrintInfo     *pi,
 				       font_size);
 	gnome_print_setfont (pi->pc, font);
 
+        if (shadow_state)
+        {
+                gnome_print_setrgbcolor (pi->pc,
+                                         GL_COLOR_F_RED (shadow_color),
+                                         GL_COLOR_F_GREEN (shadow_color),
+                                         GL_COLOR_F_BLUE (shadow_color));
+                gnome_print_setopacity (pi->pc, GL_COLOR_F_ALPHA (shadow_color));
+
+                for (i = 0; line[i] != NULL; i++) {
+
+                        glyphlist = gnome_glyphlist_from_text_dumb (font, color,
+                                                                    0.0, 0.0,
+                                                                    (guchar *)line[i]);
+
+                        gnome_glyphlist_bbox (glyphlist, affine, 0, &bbox);
+                        w = bbox.x1;
+                        gnome_glyphlist_unref (glyphlist);
+
+                        switch (just) {
+                        case GTK_JUSTIFY_LEFT:
+                                x_offset = GL_LABEL_TEXT_MARGIN;
+                                break;
+                        case GTK_JUSTIFY_CENTER:
+                                x_offset = (object_w - GL_LABEL_TEXT_MARGIN - w) / 2.0;
+                                break;
+                        case GTK_JUSTIFY_RIGHT:
+                                x_offset = object_w - GL_LABEL_TEXT_MARGIN - w;
+                                break;
+                        default:
+                                x_offset = 0.0;
+                                break;	/* shouldn't happen */
+                        }
+                        x_offset += shadow_x;
+
+                        /* Work out the y position to the BOTTOM of the first line */
+                        y_offset = GL_LABEL_TEXT_MARGIN +
+                                + gnome_font_get_descender (font)
+                                + (i + 1) * font_size * text_line_spacing
+                                + shadow_y;
+
+                        /* Remove any text line spacing from the first row. */
+                        y_offset -= font_size * (text_line_spacing - 1);
+
+
+                        gnome_print_moveto (pi->pc, x_offset, y_offset);
+
+                        gnome_print_gsave (pi->pc);
+                        gnome_print_scale (pi->pc, 1.0, -1.0);
+                        gnome_print_show (pi->pc, (guchar *)line[i]);
+                        gnome_print_grestore (pi->pc);
+                }
+        }
+
 	gnome_print_setrgbcolor (pi->pc,
 				 GL_COLOR_F_RED (color),
 				 GL_COLOR_F_GREEN (color),
@@ -891,6 +962,12 @@ draw_box_object (PrintInfo  *pi,
 	glColorNode *line_color_node;
 	glColorNode *fill_color_node;
 	guint        fill_color;
+	gboolean     shadow_state;
+	gdouble      shadow_x, shadow_y;
+	glColorNode *shadow_color_node;
+	gdouble      shadow_opacity;
+	guint        shadow_line_color;
+	guint        shadow_fill_color;
 
 	gl_debug (DEBUG_PRINT, "START");
 
@@ -903,7 +980,41 @@ draw_box_object (PrintInfo  *pi,
 	fill_color = gl_color_node_expand (fill_color_node, record);
 	gl_color_node_free (&line_color_node);
 	gl_color_node_free (&fill_color_node);
+
+	shadow_state = gl_label_object_get_shadow_state (GL_LABEL_OBJECT (object));
+	gl_label_object_get_shadow_offset (GL_LABEL_OBJECT (object), &shadow_x, &shadow_y);
+	shadow_color_node = gl_label_object_get_shadow_color (GL_LABEL_OBJECT (object));
+	if (shadow_color_node->field_flag)
+	{
+		shadow_color_node->color = GL_COLOR_SHADOW_MERGE_DEFAULT;
+	}
+	shadow_opacity = gl_label_object_get_shadow_opacity (GL_LABEL_OBJECT (object));
+	shadow_line_color = gl_color_shadow (shadow_color_node->color, shadow_opacity, line_color);
+	shadow_fill_color = gl_color_shadow (shadow_color_node->color, shadow_opacity, fill_color);
+	gl_color_node_free (&shadow_color_node);
 	
+	if (shadow_state)
+	{
+		/* Draw fill shadow */
+		create_rectangle_path (pi->pc, shadow_x, shadow_y, w, h);
+		gnome_print_setrgbcolor (pi->pc,
+					 GL_COLOR_F_RED (shadow_fill_color),
+					 GL_COLOR_F_GREEN (shadow_fill_color),
+					 GL_COLOR_F_BLUE (shadow_fill_color));
+		gnome_print_setopacity (pi->pc, GL_COLOR_F_ALPHA (shadow_fill_color));
+		gnome_print_fill (pi->pc);
+
+		/* Draw outline shadow */
+		create_rectangle_path (pi->pc, shadow_x, shadow_y, w, h);
+		gnome_print_setrgbcolor (pi->pc,
+					 GL_COLOR_F_RED (shadow_line_color),
+					 GL_COLOR_F_GREEN (shadow_line_color),
+					 GL_COLOR_F_BLUE (shadow_line_color));
+		gnome_print_setopacity (pi->pc, GL_COLOR_F_ALPHA (shadow_line_color));
+		gnome_print_setlinewidth (pi->pc, line_width);
+		gnome_print_stroke (pi->pc);
+	}
+
 	/* Paint fill color */
 	create_rectangle_path (pi->pc, 0.0, 0.0, w, h);
 	gnome_print_setrgbcolor (pi->pc,
@@ -938,6 +1049,11 @@ draw_line_object (PrintInfo   *pi,
 	gdouble      line_width;
 	guint        line_color;
 	glColorNode *line_color_node;
+	gboolean     shadow_state;
+	gdouble      shadow_x, shadow_y;
+	glColorNode *shadow_color_node;
+	gdouble      shadow_opacity;
+	guint        shadow_line_color;
 
 	gl_debug (DEBUG_PRINT, "START");
 
@@ -948,6 +1064,30 @@ draw_line_object (PrintInfo   *pi,
 	line_color = gl_color_node_expand (line_color_node, record);
 	gl_color_node_free (&line_color_node);
 
+	shadow_state = gl_label_object_get_shadow_state (GL_LABEL_OBJECT (object));
+	gl_label_object_get_shadow_offset (GL_LABEL_OBJECT (object), &shadow_x, &shadow_y);
+	shadow_color_node = gl_label_object_get_shadow_color (GL_LABEL_OBJECT (object));
+	if (shadow_color_node->field_flag)
+	{
+		shadow_color_node->color = GL_COLOR_SHADOW_MERGE_DEFAULT;
+	}
+	shadow_opacity = gl_label_object_get_shadow_opacity (GL_LABEL_OBJECT (object));
+	shadow_line_color = gl_color_shadow (shadow_color_node->color, shadow_opacity, line_color);
+	gl_color_node_free (&shadow_color_node);
+
+	if (shadow_state)
+	{
+		gnome_print_moveto (pi->pc, shadow_x, shadow_y);
+		gnome_print_lineto (pi->pc, shadow_x + w, shadow_y + h);
+		gnome_print_setrgbcolor (pi->pc,
+					 GL_COLOR_F_RED (shadow_line_color),
+					 GL_COLOR_F_GREEN (shadow_line_color),
+					 GL_COLOR_F_BLUE (shadow_line_color));
+		gnome_print_setopacity (pi->pc, GL_COLOR_F_ALPHA (shadow_line_color));
+		gnome_print_setlinewidth (pi->pc, line_width);
+		gnome_print_stroke (pi->pc);
+	}
+
 	gnome_print_moveto (pi->pc, 0.0, 0.0);
 	gnome_print_lineto (pi->pc, w, h);
 	gnome_print_setrgbcolor (pi->pc,
@@ -975,6 +1115,12 @@ draw_ellipse_object (PrintInfo      *pi,
 	glColorNode *fill_color_node;
 	guint        line_color;
 	guint        fill_color;
+	gboolean     shadow_state;
+	gdouble      shadow_x, shadow_y;
+	glColorNode *shadow_color_node;
+	gdouble      shadow_opacity;
+	guint        shadow_line_color;
+	guint        shadow_fill_color;
 
 	gl_debug (DEBUG_PRINT, "START");
 
@@ -993,6 +1139,40 @@ draw_ellipse_object (PrintInfo      *pi,
 	x0 = rx;
 	y0 = ry;
 
+	shadow_state = gl_label_object_get_shadow_state (GL_LABEL_OBJECT (object));
+	gl_label_object_get_shadow_offset (GL_LABEL_OBJECT (object), &shadow_x, &shadow_y);
+	shadow_color_node = gl_label_object_get_shadow_color (GL_LABEL_OBJECT (object));
+	if (shadow_color_node->field_flag)
+	{
+		shadow_color_node->color = GL_COLOR_SHADOW_MERGE_DEFAULT;
+	}
+	shadow_opacity = gl_label_object_get_shadow_opacity (GL_LABEL_OBJECT (object));
+	shadow_line_color = gl_color_shadow (shadow_color_node->color, shadow_opacity, line_color);
+	shadow_fill_color = gl_color_shadow (shadow_color_node->color, shadow_opacity, fill_color);
+	gl_color_node_free (&shadow_color_node);
+	
+	if (shadow_state)
+	{
+		/* Draw fill shadow */
+		create_ellipse_path (pi->pc, x0+shadow_x, y0+shadow_y, rx, ry);
+		gnome_print_setrgbcolor (pi->pc,
+					 GL_COLOR_F_RED (shadow_fill_color),
+					 GL_COLOR_F_GREEN (shadow_fill_color),
+					 GL_COLOR_F_BLUE (shadow_fill_color));
+		gnome_print_setopacity (pi->pc, GL_COLOR_F_ALPHA (shadow_fill_color));
+		gnome_print_fill (pi->pc);
+
+		/* Draw outline shadow */
+		create_ellipse_path (pi->pc, x0+shadow_x, y0+shadow_y, rx, ry);
+		gnome_print_setrgbcolor (pi->pc,
+					 GL_COLOR_F_RED (shadow_line_color),
+					 GL_COLOR_F_GREEN (shadow_line_color),
+					 GL_COLOR_F_BLUE (shadow_line_color));
+		gnome_print_setopacity (pi->pc, GL_COLOR_F_ALPHA (shadow_line_color));
+		gnome_print_setlinewidth (pi->pc, line_width);
+		gnome_print_stroke (pi->pc);
+	}
+
 	/* Paint fill color */
 	create_ellipse_path (pi->pc, x0, y0, rx, ry);
 	gnome_print_setrgbcolor (pi->pc,
@@ -1102,6 +1282,16 @@ draw_barcode_object (PrintInfo      *pi,
 	gl_label_object_get_size (GL_LABEL_OBJECT(object), &w, &h);
 
 	text = gl_text_node_expand (text_node, record);
+
+	if (text == NULL || *text == '\0') {
+
+		g_free(text);
+		gl_text_node_free(&text_node);
+		g_free(id);
+
+		return;
+	}
+
 	gbc = gl_barcode_new (id, text_flag, checksum_flag, w, h, text);
 	g_free (text);
 	gl_text_node_free (&text_node);
