@@ -22,10 +22,10 @@
 
 #include <config.h>
 
-#include <math.h>
-
 #include "view-highlight.h"
 
+#include <math.h>
+
 #include "debug.h"
 
 /*===========================================*/
@@ -219,6 +219,10 @@ gl_view_highlight_finalize (GObject *object)
 
 	gtk_object_destroy (GTK_OBJECT(view_highlight->private->position_group));
 
+	if (view_highlight->private) {
+		g_free (view_highlight->private);
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 
 	gl_debug (DEBUG_VIEW, "END");
@@ -273,7 +277,7 @@ gl_view_highlight_new (glViewObject         *view_object,
 		break;
 
 	default:
-		g_warning ("Invalid resizable highlight style");
+		g_message ("Invalid resizable highlight style");
 
 	}
 
@@ -365,7 +369,7 @@ highlight_resizable_box_construct (glViewHighlight        *view_highlight,
 		break;
 	default:
 		view_highlight->private->outline = NULL;
-		g_warning ("Invalid resizable highlight style");
+		g_message ("Invalid resizable highlight style");
 	}
 #endif
 
@@ -736,7 +740,7 @@ object_changed_cb (glLabelObject   *object,
 		break;
 
 	default:
-		g_warning ("Invalid resizable highlight style");
+		g_message ("Invalid resizable highlight style");
 
 	}
 
@@ -772,7 +776,7 @@ view_scale_changed_cb (glView          *view,
 		break;
 
 	default:
-		g_warning ("Invalid resizable highlight style");
+		g_message ("Invalid resizable highlight style");
 
 	}
 
