@@ -1,9 +1,11 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
  *  view.h:  GLabels View module header file
  *
- *  Copyright (C) 2001-2002  Jim Evins <evins@snaught.com>.
+ *  Copyright (C) 2001-2005  Jim Evins <evins@snaught.com>.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +25,8 @@
 #ifndef __VIEW_H__
 #define __VIEW_H__
 
-#include <gtk/gtk.h>
+#include <gtk/gtkvbox.h>
+#include <gtk/gtkenums.h>
 #include <libgnomecanvas/libgnomecanvas.h>
 #include <libgnomeprint/gnome-font.h>
 
@@ -44,6 +47,7 @@ typedef struct _glView      glView;
 typedef struct _glViewClass glViewClass;
 
 #include "view-object.h"
+#include "color.h"
 
 struct _glView {
 	GtkVBox           parent_widget;
@@ -75,18 +79,6 @@ struct _glView {
 	glLabel           *selection_data;
 	GtkWidget         *invisible;
 
-	/* Menus */
-	GList             *atomic_selection_items;
-	GList             *multi_selection_items;
-	GtkWidget         *selection_menu;
-	GtkWidget         *empty_selection_menu;
-
-	/* Merge Properties Dialog */
-	GtkWidget         *merge_props_dialog;
-
-	/* Print Dialog */
-	GtkWidget         *print_dialog;
-
 	/* Default object text properties */
 	gchar             *default_font_family;
 	gdouble            default_font_size;
@@ -111,6 +103,12 @@ struct _glViewClass {
 	void (*selection_changed) (glView   *view,
 				   gpointer  user_data);
 
+	/* Signal to launch a context menu */
+	void (*context_menu_activate) (glView   *view,
+				       gint      button,
+				       guint32   activate_time,
+				       gpointer  user_data);
+
 	/* Signals to support a status bar */
 	void (*zoom_changed)      (glView   *view,
 				   gdouble   zoom,
@@ -232,17 +230,17 @@ void       gl_view_set_selection_text_alignment   (glView           *view,
 						   GtkJustification  text_alignment);
 
 void       gl_view_set_selection_text_color       (glView           *view,
-						   guint             text_color);
+						   glColorNode      *text_color_node);
 
 gboolean   gl_view_can_selection_fill             (glView           *view);
 
 void       gl_view_set_selection_fill_color       (glView           *view,
-						   guint             fill_color);
+						   glColorNode      *fill_color);
 
 gboolean   gl_view_can_selection_line_color       (glView           *view);
 
 void       gl_view_set_selection_line_color       (glView           *view,
-						   guint             line_color);
+						   glColorNode      *line_color_node);
 
 gboolean   gl_view_can_selection_line_width       (glView           *view);
 
@@ -273,12 +271,6 @@ gboolean   gl_view_is_zoom_max             (glView            *view);
 gboolean   gl_view_is_zoom_min             (glView            *view);
 
 
-void       gl_view_popup_menu              (glView            *view,
-					    GdkEvent          *event);
-
-void       gl_view_edit_merge_props        (glView            *view);
-
-
 void       gl_view_set_default_font_family      (glView            *view,
 						 const gchar       *font_family);
 
