@@ -22,9 +22,11 @@
 
 #include <config.h>
 
+#include "wdgt-mini-preview.h"
+
+#include <libgnomecanvas/gnome-canvas-util.h>
 #include <math.h>
 
-#include "wdgt-mini-preview.h"
 #include "marshal.h"
 #include "color.h"
 
@@ -423,7 +425,7 @@ mini_outline_list_new (GnomeCanvas       *canvas,
 			}
 			break;
 		default:
-			g_warning ("Unknown label style");
+			g_message ("Unknown label style");
 			return list;
 			break;
 		}
@@ -433,6 +435,8 @@ mini_outline_list_new (GnomeCanvas       *canvas,
 		list = g_list_append (list, item);
 	}
 
+	g_free (origins);
+
 	gl_debug (DEBUG_MINI_PREVIEW, "END");
 	return list;
 }
