@@ -23,6 +23,13 @@
 #include <config.h>
 
 #include "wdgt-print-copies.h"
+
+#include <glib/gi18n.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtkradiobutton.h>
+#include <gtk/gtklabel.h>
+
 #include "wdgt-mini-preview.h"
 #include "marshal.h"
 
