@@ -22,9 +22,14 @@
 
 #include <config.h>
 
+#include "wdgt-rotate-label.h"
+
+#include <glib/gi18n.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkcheckbutton.h>
+#include <libgnomecanvas/gnome-canvas-util.h>
 #include <math.h>
 
-#include "wdgt-rotate-label.h"
 #include "hig.h"
 #include "marshal.h"
 #include "color.h"
@@ -163,6 +168,11 @@ gl_wdgt_rotate_label_finalize (GObject *object)
 
 	rotate_select = GL_WDGT_ROTATE_LABEL (object);
 
+	if (rotate_select->template) {
+		gl_template_free (rotate_select->template);
+		rotate_select->template = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -340,7 +350,7 @@ mini_preview_canvas_update (GnomeCanvas *canvas,
 		}
 		break;
 	default:
-		g_warning ("Unknown label style");
+		g_message ("Unknown label style");
 		break;
 	}
 
