@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
@@ -23,15 +25,16 @@
 #ifndef __WINDOW_H__
 #define __WINDOW_H__
 
-#include <gtk/gtk.h>
-#include <bonobo/bonobo-window.h>
-#include <bonobo/bonobo-ui-component.h>
+#include <gtk/gtkwindow.h>
+#include <gtk/gtkuimanager.h>
+#include <gtk/gtkmenu.h>
 
 #include "view.h"
 #include "label.h"
-
 #include "ui-property-bar.h"
 #include "ui-sidebar.h"
+#include "print-dialog.h"
+#include "merge-properties-dialog.h"
 
 G_BEGIN_DECLS
 
@@ -49,23 +52,33 @@ typedef struct _glWindow      glWindow;
 typedef struct _glWindowClass glWindowClass;
 
 struct _glWindow {
-	BonoboWindow         parent_widget;
+	GtkWindow               parent_widget;
 
-	BonoboUIComponent   *uic;
+	GtkUIManager            *ui;
 
-	GtkWidget           *view;
+	GtkWidget               *view;
 
-	glUIPropertyBar     *property_bar;
-	glUISidebar         *sidebar;
+	GtkWidget               *hbox;
 
-	GtkWidget           *cursor_info;
-	GtkWidget           *cursor_info_frame;
-	GtkWidget           *zoom_info;
-	GtkWidget           *zoom_info_frame;
+	glUIPropertyBar         *property_bar;
+	glUISidebar             *sidebar;
+
+	GtkWidget               *status_bar;
+	GtkWidget               *cursor_info;
+	GtkWidget               *cursor_info_frame;
+	GtkWidget               *zoom_info;
+	GtkWidget               *zoom_info_frame;
+
+	guint                    menu_tips_context_id;
+
+	glPrintDialog           *print_dialog;
+	glMergePropertiesDialog *merge_dialog;
+	GtkMenu                 *context_menu;
+	GtkMenu                 *empty_selection_context_menu;
 };
 
 struct _glWindowClass {
-	BonoboWindowClass    parent_class;
+	GtkWindowClass          parent_class;
 };
 
 GType        gl_window_get_type          (void) G_GNUC_CONST;
