@@ -22,9 +22,10 @@
 
 #include <config.h>
 
-#include <gnome.h>
-
 #include "xml-label-04.h"
+
+#include <glib/gi18n.h>
+
 #include "label-text.h"
 #include "label-box.h"
 #include "label-line.h"
@@ -71,8 +72,8 @@ glLabel      *gl_xml_label_04_parse      (xmlNodePtr       root,
 
 	*status = XML_LABEL_OK;
 
-	if (!xmlStrEqual (root->name, "Label")) {
-		g_warning (_("Bad root node = \"%s\""), root->name);
+	if (!xmlStrEqual (root->name, (xmlChar *)"Label")) {
+		g_message (_("Bad root node = \"%s\""), root->name);
 		*status = XML_LABEL_ERROR_OPEN_PARSE;
 		return NULL;
 	}
@@ -87,40 +88,40 @@ glLabel      *gl_xml_label_04_parse      (xmlNodePtr       root,
 		gl_debug (DEBUG_XML, "node name = \"%s\"", node->name);
 
 		if (!xmlNodeIsText (node)) {
-			if (xmlStrEqual (node->name, "Media_Type")) {
+			if (xmlStrEqual (node->name, (xmlChar *)"Media_Type")) {
 				if (!xml04_parse_media_description (node, label)) {
 					*status = XML_LABEL_UNKNOWN_MEDIA;
 				}
-			} else if (xmlStrEqual (node->name, "Text")) {
+			} else if (xmlStrEqual (node->name, (xmlChar *)"Text")) {
 				object = gl_label_text_new (label);
 				xml04_parse_object (node, GL_LABEL_OBJECT(object));
 				xml04_parse_text_props (node, GL_LABEL_TEXT(object));
-			} else if (xmlStrEqual (node->name, "Box")) {
+			} else if (xmlStrEqual (node->name, (xmlChar *)"Box")) {
 				object = gl_label_box_new (label);
 				xml04_parse_object (node, GL_LABEL_OBJECT(object));
 				xml04_parse_box_props (node, GL_LABEL_BOX(object));
-			} else if (xmlStrEqual (node->name, "Line")) {
+			} else if (xmlStrEqual (node->name, (xmlChar *)"Line")) {
 				object = gl_label_line_new (label);
 				xml04_parse_object (node, GL_LABEL_OBJECT(object));
 				xml04_parse_line_props (node, GL_LABEL_LINE(object));
-			} else if (xmlStrEqual (node->name, "Ellipse")) {
+			} else if (xmlStrEqual (node->name, (xmlChar *)"Ellipse")) {
 				object = gl_label_ellipse_new (label);
 				xml04_parse_object (node, GL_LABEL_OBJECT(object));
 				xml04_parse_ellipse_props (node,
 							   GL_LABEL_ELLIPSE(object));
-			} else if (xmlStrEqual (node->name, "Image")) {
+			} else if (xmlStrEqual (node->name, (xmlChar *)"Image")) {
 				object = gl_label_image_new (label);
 				xml04_parse_object (node, GL_LABEL_OBJECT(object));
 				xml04_parse_image_props (node, GL_LABEL_IMAGE(object));
-			} else if (xmlStrEqual (node->name, "Barcode")) {
+			} else if (xmlStrEqual (node->name, (xmlChar *)"Barcode")) {
 				object = gl_label_barcode_new (label);
 				xml04_parse_object (node, GL_LABEL_OBJECT(object));
 				xml04_parse_barcode_props (node,
 							   GL_LABEL_BARCODE(object));
-			} else if (xmlStrEqual (node->name, "Merge_Properties")) {
+			} else if (xmlStrEqual (node->name, (xmlChar *)"Merge_Properties")) {
 				xml04_parse_merge_properties (node, label);
 			} else {
-				g_warning (_("bad node =  \"%s\""), node->name);
+				g_message (_("bad node =  \"%s\""), node->name);
 			}
 		}
 	}
@@ -137,7 +138,7 @@ static gboolean
 xml04_parse_media_description (xmlNodePtr node,
 			       glLabel    *label)
 {
-	gchar      *template_name;
+	xmlChar    *template_name;
 	glTemplate *template;
 	gboolean   ret;
 
@@ -145,9 +146,9 @@ xml04_parse_media_description (xmlNodePtr node,
 
 	template_name = xmlNodeGetContent (node);
 
-	template = gl_template_from_name (template_name);
+	template = gl_template_from_name ((gchar *)template_name);
 	if (template == NULL) {
-		g_warning ("Undefined template \"%s\"", template_name);
+		g_message ("Undefined template \"%s\"", template_name);
 		/* Get a default */
 		template = gl_template_from_name (NULL);
 		ret = FALSE;
@@ -158,7 +159,7 @@ xml04_parse_media_description (xmlNodePtr node,
 	gl_label_set_template (label, template);
 
 	gl_template_free (template);
-	g_free (template_name);
+	xmlFree (template_name);
 
 	gl_debug (DEBUG_XML, "END");
 
@@ -191,45 +192,48 @@ static void
 xml04_parse_text_props (xmlNodePtr    object_node,
 			glLabelText   *object)
 {
-	gchar            *font_family;
+	xmlChar         *font_family;
 	gdouble          font_size;
 	GnomeFontWeight  font_weight;
 	gboolean         font_italic_flag;
-	guint            color;
+	glColorNode     *color_node;
 	GtkJustification just;
 	xmlNodePtr       line_node, text_node;
-	glTextNode       *node_text;
-	GList            *nodes, *lines;
+	glTextNode      *node_text;
+	GList           *nodes, *lines;
 	gdouble          w, h, x, y;
-	gchar            *string;
+	xmlChar         *string;
 
 	gl_debug (DEBUG_XML, "START");
 
-	font_family = xmlGetProp (object_node, "font_family");
+	font_family = xmlGetProp (object_node, (xmlChar *)"font_family");
 	font_size = gl_xml_get_prop_double (object_node, "font_size", 0);
-	string = xmlGetProp (object_node, "font_weight");
+	string = xmlGetProp (object_node, (xmlChar *)"font_weight");
 	font_weight = gl_util_string_to_weight (string);
-	g_free (string);
+	xmlFree (string);
 	font_italic_flag = gl_xml_get_prop_boolean (object_node, "font_italic", FALSE);
 
-	string = xmlGetProp (object_node, "justify");
+	string = xmlGetProp (object_node, (xmlChar *)"justify");
 	just = gl_util_string_to_just (string);
-	g_free (string);
+	xmlFree (string);
 
-	color = gl_xml_get_prop_uint (object_node, "color", 0);
+	color_node = gl_color_node_new_default ();
+	color_node->color = gl_xml_get_prop_uint (object_node, "color", 0);
 
-	gl_label_object_set_font_family (GL_LABEL_OBJECT(object), font_family);
+	gl_label_object_set_font_family (GL_LABEL_OBJECT(object), (gchar *)font_family);
 	gl_label_object_set_font_size (GL_LABEL_OBJECT(object), font_size);
 	gl_label_object_set_font_weight (GL_LABEL_OBJECT(object), font_weight);
 	gl_label_object_set_font_italic_flag (GL_LABEL_OBJECT(object), font_italic_flag);
-	gl_label_object_set_text_color (GL_LABEL_OBJECT(object), color);
+	gl_label_object_set_text_color (GL_LABEL_OBJECT(object), color_node);
 	gl_label_object_set_text_alignment (GL_LABEL_OBJECT(object), just);
+	
+	gl_color_node_free (&color_node);
 
 	lines = NULL;
 	for (line_node = object_node->xmlChildrenNode; line_node != NULL;
 	     line_node = line_node->next) {
 
-		if (xmlStrEqual (line_node->name, "Line")) {
+		if (xmlStrEqual (line_node->name, (xmlChar *)"Line")) {
 
 			gl_debug (DEBUG_XML, "->Line node");
 
@@ -237,12 +241,12 @@ xml04_parse_text_props (xmlNodePtr    object_node,
 			for (text_node = line_node->xmlChildrenNode;
 			     text_node != NULL; text_node = text_node->next) {
 
-				if (xmlStrEqual (text_node->name, "Field")) {
+				if (xmlStrEqual (text_node->name, (xmlChar *)"Field")) {
 					gl_debug (DEBUG_XML, "->Line->Field node");
 					node_text = g_new0 (glTextNode, 1);
 					node_text->field_flag = TRUE;
 					node_text->data =
-					    xmlGetProp (text_node, "name");
+						(gchar *)xmlGetProp (text_node, (xmlChar *)"name");
 					nodes =
 					    g_list_append (nodes, node_text);
 				} else if (xmlNodeIsText (text_node)) {
@@ -250,13 +254,13 @@ xml04_parse_text_props (xmlNodePtr    object_node,
 					node_text = g_new0 (glTextNode, 1);
 					node_text->field_flag = FALSE;
 					node_text->data =
-					    xmlNodeGetContent (text_node);
+						(gchar *)xmlNodeGetContent (text_node);
 					gl_debug (DEBUG_XML, "text = \"%s\"",
 						  node_text->data);
 					nodes =
 					    g_list_append (nodes, node_text);
 				} else {
-					g_warning ("Unexpected Text Line child: \"%s\"",
+					g_message ("Unexpected Text Line child: \"%s\"",
 						   text_node->name);
 				}
 
@@ -264,7 +268,7 @@ xml04_parse_text_props (xmlNodePtr    object_node,
 			lines = g_list_append (lines, nodes);
 
 		} else if (!xmlNodeIsText (line_node)) {
-			g_warning ("Unexpected Text child: \"%s\"",
+			g_message ("Unexpected Text child: \"%s\"",
 				   line_node->name);
 		}
 
@@ -273,7 +277,7 @@ xml04_parse_text_props (xmlNodePtr    object_node,
 	gl_label_text_set_lines (object, lines);
 
 	gl_text_node_lines_free (&lines);
-	g_free (font_family);
+	xmlFree (font_family);
 
 	/* Adjust location.  In 0.4.x, text was anchored at x,y */
 	gl_label_object_get_position (GL_LABEL_OBJECT(object), &x, &y);
@@ -306,7 +310,8 @@ xml04_parse_box_props (xmlNodePtr    node,
 		       glLabelBox    *object)
 {
 	gdouble w, h, line_width;
-	guint line_color, fill_color;
+	glColorNode *line_color_node;
+	glColorNode *fill_color_node;
 
 	gl_debug (DEBUG_XML, "START");
 
@@ -315,14 +320,19 @@ xml04_parse_box_props (xmlNodePtr    node,
 
 	line_width = gl_xml_get_prop_double (node, "line_width", 0);
 
-	line_color = gl_xml_get_prop_uint (node, "line_color", 0);
-	fill_color = gl_xml_get_prop_uint (node, "fill_color", 0);
+	line_color_node = gl_color_node_new_default ();
+	line_color_node->color = gl_xml_get_prop_uint (node, "line_color", 0);
+	
+	fill_color_node = gl_color_node_new_default ();
+	fill_color_node->color = gl_xml_get_prop_uint (node, "fill_color", 0);
 
 	gl_label_object_set_size (GL_LABEL_OBJECT(object), w, h);
 	gl_label_object_set_line_width (GL_LABEL_OBJECT(object), line_width);
-	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color);
-	gl_label_object_set_fill_color (GL_LABEL_OBJECT(object), fill_color);
+	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color_node);
+	gl_label_object_set_fill_color (GL_LABEL_OBJECT(object), fill_color_node);
 
+	gl_color_node_free (&line_color_node);
+	gl_color_node_free (&fill_color_node);
 	gl_debug (DEBUG_XML, "END");
 }
 
@@ -334,7 +344,7 @@ xml04_parse_line_props (xmlNodePtr    node,
 			glLabelLine *object)
 {
 	gdouble w, h, line_width;
-	guint line_color;
+	glColorNode *line_color_node;
 
 	gl_debug (DEBUG_XML, "START");
 
@@ -343,12 +353,15 @@ xml04_parse_line_props (xmlNodePtr    node,
 
 	line_width = gl_xml_get_prop_double (node, "line_width", 0);
 
-	line_color = gl_xml_get_prop_uint (node, "line_color", 0);
+	line_color_node = gl_color_node_new_default ();
+	line_color_node->color = gl_xml_get_prop_uint (node, "line_color", 0);
 
 	gl_label_object_set_size (GL_LABEL_OBJECT(object), w, h);
 	gl_label_object_set_line_width (GL_LABEL_OBJECT(object), line_width);
-	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color);
+	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color_node);
 
+	gl_color_node_free (&line_color_node);
+	
 	gl_debug (DEBUG_XML, "END");
 }
 
@@ -360,7 +373,8 @@ xml04_parse_ellipse_props (xmlNodePtr     node,
 			   glLabelEllipse *object)
 {
 	gdouble w, h, line_width;
-	guint line_color, fill_color;
+	glColorNode *line_color_node;
+	glColorNode *fill_color_node;
 
 	gl_debug (DEBUG_XML, "START");
 
@@ -369,14 +383,19 @@ xml04_parse_ellipse_props (xmlNodePtr     node,
 
 	line_width = gl_xml_get_prop_double (node, "line_width", 0);
 
-	line_color = gl_xml_get_prop_uint (node, "line_color", 0);
-	fill_color = gl_xml_get_prop_uint (node, "fill_color", 0);
+	line_color_node = gl_color_node_new_default ();
+	line_color_node->color = gl_xml_get_prop_uint (node, "line_color", 0);
+	
+	fill_color_node = gl_color_node_new_default ();
+	fill_color_node->color = gl_xml_get_prop_uint (node, "fill_color", 0);
 
 	gl_label_object_set_size (GL_LABEL_OBJECT(object), w, h);
 	gl_label_object_set_line_width (GL_LABEL_OBJECT(object), line_width);
-	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color);
-	gl_label_object_set_fill_color (GL_LABEL_OBJECT(object), fill_color);
+	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color_node);
+	gl_label_object_set_fill_color (GL_LABEL_OBJECT(object), fill_color_node);
 
+	gl_color_node_free (&line_color_node);
+	gl_color_node_free (&fill_color_node);
 	gl_debug (DEBUG_XML, "END");
 }
 
@@ -394,7 +413,7 @@ xml04_parse_image_props (xmlNodePtr    node,
 
 	filename = g_new0 (glTextNode, 1);
 	filename->field_flag = FALSE;
-	filename->data = xmlGetProp (node, "filename");
+	filename->data = (gchar *)xmlGetProp (node, (xmlChar *)"filename");
 	gl_label_image_set_filename (object, filename);
 	gl_text_node_free (&filename);
 
@@ -412,43 +431,44 @@ static void
 xml04_parse_barcode_props (xmlNodePtr    node,
 			   glLabelBarcode *object)
 {
-	gchar         *id;
+	xmlChar       *id;
 	gboolean       text_flag;
-	guint          color;
+	glColorNode   *color_node;
 	gdouble        scale;
 	xmlNodePtr     child;
-	glTextNode     *text_node;
-	gchar          *string;
+	glTextNode    *text_node;
 
 	gl_debug (DEBUG_XML, "START");
 
-	color = gl_xml_get_prop_uint (node, "color", 0);
+	color_node = gl_color_node_new_default ();
+	color_node->color = gl_xml_get_prop_uint (node, "color", 0);
 
-	id = xmlGetProp (node, "style");
+	id = xmlGetProp (node, (xmlChar *)"style");
 
 	text_flag = gl_xml_get_prop_boolean (node, "text", FALSE);
 	scale =	gl_xml_get_prop_double (node, "scale", 1.0);
 	if (scale == 0.0) {
 		scale = 0.5; /* Set to a valid value */
 	}
-	gl_label_barcode_set_props (object, id, text_flag, TRUE, 0);
-	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), color);
+	gl_label_barcode_set_props (object, (gchar *)id, text_flag, TRUE, 0);
+	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), color_node);
 
 	child = node->xmlChildrenNode;
 	text_node = g_new0 (glTextNode, 1);
-	if (xmlStrEqual (child->name, "Field")) {
+	if (xmlStrEqual (child->name, (xmlChar *)"Field")) {
 		text_node->field_flag = TRUE;
-		text_node->data       = xmlGetProp (child, "name");
+		text_node->data       = (gchar *)xmlGetProp (child, (xmlChar *)"name");
 	} else if (xmlNodeIsText (child)) {
 		text_node->field_flag = FALSE;
-		text_node->data       = xmlNodeGetContent (child);
+		text_node->data       = (gchar *)xmlNodeGetContent (child);
 	} else {
-		g_warning ("Unexpected Barcode child: \"%s\"", child->name);
+		g_message ("Unexpected Barcode child: \"%s\"", child->name);
 	}
 	gl_label_barcode_set_data (object, text_node);
 
+	gl_color_node_free (&color_node);
 	gl_text_node_free (&text_node);
-	g_free (id);
+	xmlFree (id);
 
 	gl_debug (DEBUG_XML, "END");
 }
@@ -460,19 +480,19 @@ static void
 xml04_parse_merge_properties (xmlNodePtr node,
 			      glLabel    *label)
 {
-	glMerge                *merge;
+	glMerge               *merge;
 	xmlNodePtr             child;
-	gchar                  *string;
+	xmlChar               *string;
 
 	gl_debug (DEBUG_XML, "START");
 
-	string = xmlGetProp (node, "type");
-	merge = gl_merge_new (string);
-	g_free (string);
+	string = xmlGetProp (node, (xmlChar *)"type");
+	merge = gl_merge_new ((gchar *)string);
+	xmlFree (string);
 
-	string = xmlGetProp (node, "src");
-	gl_merge_set_src (merge, string);
-	g_free (string);
+	string = xmlGetProp (node, (xmlChar *)"src");
+	gl_merge_set_src (merge, (gchar *)string);
+	xmlFree (string);
 
 	gl_label_set_merge (label, merge);
 
@@ -480,4 +500,3 @@ xml04_parse_merge_properties (xmlNodePtr node,
 
 	gl_debug (DEBUG_XML, "END");
 }
-
