@@ -22,8 +22,9 @@
 
 #include <config.h>
 
-#include <gnome.h>
+#include "xml-label-191.h"
 
+#include <glib/gi18n.h>
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
@@ -38,7 +39,6 @@
 #include "label-barcode.h"
 #include "base64.h"
 #include "xml-label.h"
-#include "xml-label-04.h"
 #include <libglabels/paper.h>
 #include <libglabels/template.h>
 #include <libglabels/xml-template.h>
@@ -127,8 +127,8 @@ gl_xml_label_191_parse (xmlNodePtr        root,
 
 	*status = XML_LABEL_OK;
 
-	if (!xmlStrEqual (root->name, "Document")) {
-		g_warning (_("Bad root node = \"%s\""), root->name);
+	if (!xmlStrEqual (root->name, (xmlChar *)"Document")) {
+		g_message (_("Bad root node = \"%s\""), root->name);
 		*status = XML_LABEL_ERROR_OPEN_PARSE;
 		return NULL;
 	}
@@ -137,7 +137,7 @@ gl_xml_label_191_parse (xmlNodePtr        root,
 
 	/* Pass 1, extract data nodes to pre-load cache. */
 	for (node = root->xmlChildrenNode; node != NULL; node = node->next) {
-		if (xmlStrEqual (node->name, "Data")) {
+		if (xmlStrEqual (node->name, (xmlChar *)"Data")) {
 			xml191_parse_data (node, label);
 		}
 	}
@@ -145,7 +145,7 @@ gl_xml_label_191_parse (xmlNodePtr        root,
 	/* Pass 2, now extract everything else. */
 	for (node = root->xmlChildrenNode; node != NULL; node = node->next) {
 
-		if (xmlStrEqual (node->name, "Sheet")) {
+		if (xmlStrEqual (node->name, (xmlChar *)"Sheet")) {
 			template = xml191_parse_sheet (node);
 			if (!template) {
 				*status = XML_LABEL_UNKNOWN_MEDIA;
@@ -154,15 +154,15 @@ gl_xml_label_191_parse (xmlNodePtr        root,
 			gl_template_register (template);
 			gl_label_set_template (label, template);
 			gl_template_free (template);
-		} else if (xmlStrEqual (node->name, "Objects")) {
+		} else if (xmlStrEqual (node->name, (xmlChar *)"Objects")) {
 			xml191_parse_objects (node, label);
-		} else if (xmlStrEqual (node->name, "Merge_Fields")) {
+		} else if (xmlStrEqual (node->name, (xmlChar *)"Merge_Fields")) {
 			xml191_parse_merge_fields (node, label);
-		} else if (xmlStrEqual (node->name, "Data")) {
+		} else if (xmlStrEqual (node->name, (xmlChar *)"Data")) {
 			/* Handled in pass 1. */
 		} else {
 			if (!xmlNodeIsText (node)) {
-				g_warning (_("bad node in Document node =  \"%s\""),
+				g_message (_("bad node in Document node =  \"%s\""),
 					   node->name);
 			}
 		}
@@ -190,11 +190,11 @@ xml191_parse_objects (xmlNodePtr  objects_node,
 
 	for (node = objects_node->xmlChildrenNode; node != NULL; node = node->next) {
 
-		if (xmlStrEqual (node->name, "Object")) {
+		if (xmlStrEqual (node->name, (xmlChar *)"Object")) {
 			xml191_parse_object (node, label);
 		} else {
 			if (!xmlNodeIsText (node)) {
-				g_warning (_("bad node =  \"%s\""), node->name);
+				g_message (_("bad node =  \"%s\""), node->name);
 			}
 		}
 	}
@@ -211,31 +211,31 @@ xml191_parse_object (xmlNodePtr  object_node,
 {
 	glLabelObject *object;
 	gdouble        x, y;
-	gchar         *string;
+	xmlChar       *string;
 	gdouble        affine[6];
 
 	gl_debug (DEBUG_XML, "START");
 
-	string = xmlGetProp (object_node, "type");
+	string = xmlGetProp (object_node, (xmlChar *)"type");
 
-	if ( xmlStrEqual (string, "Text") ) {
+	if ( xmlStrEqual (string, (xmlChar *)"Text") ) {
 		object = xml191_parse_text_props (object_node, label);
-	} else if ( xmlStrEqual (string, "Box") ) {
+	} else if ( xmlStrEqual (string, (xmlChar *)"Box") ) {
 		object = xml191_parse_box_props (object_node, label);
-	} else if ( xmlStrEqual (string, "Line") ) {
+	} else if ( xmlStrEqual (string, (xmlChar *)"Line") ) {
 		object = xml191_parse_line_props (object_node, label);
-	} else if ( xmlStrEqual (string, "Ellipse") ) {
+	} else if ( xmlStrEqual (string, (xmlChar *)"Ellipse") ) {
 		object = xml191_parse_ellipse_props (object_node, label);
-	} else if ( xmlStrEqual (string, "Image") ) {
+	} else if ( xmlStrEqual (string, (xmlChar *)"Image") ) {
 		object = xml191_parse_image_props (object_node, label);
-	} else if ( xmlStrEqual (string, "Barcode") ) {
+	} else if ( xmlStrEqual (string, (xmlChar *)"Barcode") ) {
 		object = xml191_parse_barcode_props (object_node, label);
 	} else {
-		g_warning ("Unknown label object type \"%s\"", string);
-		g_free (string);
+		g_message ("Unknown label object type \"%s\"", string);
+		xmlFree (string);
 		return;
 	}
-	g_free (string);
+	xmlFree (string);
 
 
 	x = gl_xml_get_prop_length (object_node, "x", 0.0);
@@ -267,16 +267,16 @@ xml191_parse_text_props (xmlNodePtr  object_node,
 	GObject          *object;
 	GList            *lines;
 	gdouble           w, h;
-	gchar            *font_family;
+	xmlChar          *font_family;
 	gdouble           font_size;
 	GnomeFontWeight   font_weight;
 	gboolean          font_italic_flag;
-	guint             color;
+	glColorNode      *color_node;
 	GtkJustification  just;
 	xmlNodePtr        line_node, text_node;
 	glTextNode       *node_text;
 	GList            *nodes;
-	gchar            *string;
+	xmlChar          *string;
 
 	gl_debug (DEBUG_XML, "START");
 
@@ -285,47 +285,48 @@ xml191_parse_text_props (xmlNodePtr  object_node,
 	w = gl_xml_get_prop_length (object_node, "w", 0);
 	h = gl_xml_get_prop_length (object_node, "h", 0);
 
-	font_family = xmlGetProp (object_node, "font_family");
+	font_family = xmlGetProp (object_node, (xmlChar *)"font_family");
 
 	font_size = gl_xml_get_prop_double (object_node, "font_size", 0.0);
 
-	string = xmlGetProp (object_node, "font_weight");
-	font_weight = gl_util_string_to_weight (string);
-	g_free (string);
+	string = xmlGetProp (object_node, (xmlChar *)"font_weight");
+	font_weight = gl_util_string_to_weight ((gchar *)string);
+	xmlFree (string);
 
 	font_italic_flag = gl_xml_get_prop_boolean (object_node, "font_italic", FALSE);
 
-	string = xmlGetProp (object_node, "justify");
-	just = gl_util_string_to_just (string);
-	g_free (string);
+	string = xmlGetProp (object_node, (xmlChar *)"justify");
+	just = gl_util_string_to_just ((gchar *)string);
+	xmlFree (string);
 
-	color = gl_xml_get_prop_uint (object_node, "color", 0);
+	color_node = gl_color_node_new_default ();
+	color_node->color = gl_xml_get_prop_uint (object_node, "color", 0);
 
 	lines = NULL;
 	for (line_node = object_node->xmlChildrenNode;
 	     line_node != NULL;
 	     line_node = line_node->next) {
 
-		if (xmlStrEqual (line_node->name, "Line")) {
+		if (xmlStrEqual (line_node->name, (xmlChar *)"Line")) {
 
 			nodes = NULL;
 			for (text_node = line_node->xmlChildrenNode;
 			     text_node != NULL; text_node = text_node->next) {
 
-				if (xmlStrEqual (text_node->name, "Field")) {
+				if (xmlStrEqual (text_node->name, (xmlChar *)"Field")) {
 					node_text = g_new0 (glTextNode, 1);
 					node_text->field_flag = TRUE;
-					node_text->data = xmlGetProp (text_node, "name");
+					node_text->data = (gchar *)xmlGetProp (text_node, (xmlChar *)"name");
 					nodes =	g_list_append (nodes, node_text);
-				} else if (xmlStrEqual (text_node->name, "Literal")) {
+				} else if (xmlStrEqual (text_node->name, (xmlChar *)"Literal")) {
 					node_text = g_new0 (glTextNode, 1);
 					node_text->field_flag = FALSE;
 					node_text->data =
-						xmlNodeGetContent (text_node);
+						(gchar *)xmlNodeGetContent (text_node);
 					nodes =
 						g_list_append (nodes, node_text);
 				} else if (!xmlNodeIsText (text_node)) {
-					g_warning ("Unexpected Text Line child: \"%s\"",
+					g_message ("Unexpected Text Line child: \"%s\"",
 						   text_node->name);
 				}
 
@@ -333,7 +334,7 @@ xml191_parse_text_props (xmlNodePtr  object_node,
 			lines = g_list_append (lines, nodes);
 
 		} else if (!xmlNodeIsText (line_node)) {
-			g_warning ("Unexpected Text child: \"%s\"",
+			g_message ("Unexpected Text child: \"%s\"",
 				   line_node->name);
 		}
 
@@ -341,15 +342,16 @@ xml191_parse_text_props (xmlNodePtr  object_node,
 
 	gl_label_object_set_size (GL_LABEL_OBJECT(object), w, h);
 	gl_label_text_set_lines  (GL_LABEL_TEXT(object), lines);
-	gl_label_object_set_font_family (GL_LABEL_OBJECT(object), font_family);
+	gl_label_object_set_font_family (GL_LABEL_OBJECT(object), (gchar *)font_family);
 	gl_label_object_set_font_size (GL_LABEL_OBJECT(object), font_size);
 	gl_label_object_set_font_weight (GL_LABEL_OBJECT(object), font_weight);
 	gl_label_object_set_font_italic_flag (GL_LABEL_OBJECT(object), font_italic_flag);
-	gl_label_object_set_text_color (GL_LABEL_OBJECT(object), color);
+	gl_label_object_set_text_color (GL_LABEL_OBJECT(object), color_node);
 	gl_label_object_set_text_alignment (GL_LABEL_OBJECT(object), just);
 
+	gl_color_node_free (&color_node);
 	gl_text_node_lines_free (&lines);
-	g_free (font_family);
+	xmlFree (font_family);
 
 	gl_debug (DEBUG_XML, "END");
 
@@ -365,7 +367,8 @@ xml191_parse_box_props (xmlNodePtr  node,
 {
 	GObject *object;
 	gdouble  line_width;
-	guint    line_color, fill_color;
+	glColorNode *line_color_node;
+	glColorNode *fill_color_node;
 	gdouble  w, h;
 
 	gl_debug (DEBUG_XML, "START");
@@ -377,14 +380,19 @@ xml191_parse_box_props (xmlNodePtr  node,
 
 	line_width = gl_xml_get_prop_length (node, "line_width", 1.0);
 
-	line_color = gl_xml_get_prop_uint (node, "line_color", 0);
-	fill_color = gl_xml_get_prop_uint (node, "fill_color", 0);
+	line_color_node = gl_color_node_new_default ();
+	line_color_node->color = gl_xml_get_prop_uint (node, "line_color", 0);
+	
+	fill_color_node = gl_color_node_new_default ();
+	fill_color_node->color = gl_xml_get_prop_uint (node, "fill_color", 0);
 
 	gl_label_object_set_size (GL_LABEL_OBJECT(object), w, h);
 	gl_label_object_set_line_width (GL_LABEL_OBJECT(object), line_width);
-	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color);
-	gl_label_object_set_fill_color (GL_LABEL_OBJECT(object), fill_color);
+	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color_node);
+	gl_label_object_set_fill_color (GL_LABEL_OBJECT(object), fill_color_node);
 
+	gl_color_node_free (&line_color_node);
+	gl_color_node_free (&fill_color_node);
 	gl_debug (DEBUG_XML, "END");
 
 	return GL_LABEL_OBJECT(object);
@@ -399,7 +407,7 @@ xml191_parse_line_props (xmlNodePtr  node,
 {
 	GObject *object;
 	gdouble  line_width;
-	guint    line_color;
+	glColorNode  *line_color_node;
 	gdouble  w, h;
 
 	gl_debug (DEBUG_XML, "START");
@@ -411,11 +419,14 @@ xml191_parse_line_props (xmlNodePtr  node,
 
 	line_width = gl_xml_get_prop_length (node, "line_width", 1.0);
 
-	line_color = gl_xml_get_prop_uint (node, "line_color", 0);
+	line_color_node = gl_color_node_new_default ();
+	line_color_node->color = gl_xml_get_prop_uint (node, "line_color", 0);
 
 	gl_label_object_set_size (GL_LABEL_OBJECT(object), w, h);
 	gl_label_object_set_line_width (GL_LABEL_OBJECT(object), line_width);
-	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color);
+	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color_node);
+
+	gl_color_node_free (&line_color_node);
 
 	gl_debug (DEBUG_XML, "END");
 
@@ -431,7 +442,8 @@ xml191_parse_ellipse_props (xmlNodePtr  node,
 {
 	GObject *object;
 	gdouble  line_width;
-	guint    line_color, fill_color;
+	glColorNode *line_color_node;
+	glColorNode *fill_color_node;
 	gdouble  w, h;
 
 	gl_debug (DEBUG_XML, "START");
@@ -443,14 +455,19 @@ xml191_parse_ellipse_props (xmlNodePtr  node,
 
 	line_width = gl_xml_get_prop_length (node, "line_width", 1.0);
 
-	line_color = gl_xml_get_prop_uint (node, "line_color", 0);
-	fill_color = gl_xml_get_prop_uint (node, "fill_color", 0);
+	line_color_node = gl_color_node_new_default ();
+	line_color_node->color = gl_xml_get_prop_uint (node, "line_color", 0);
+	
+	fill_color_node = gl_color_node_new_default ();
+	fill_color_node->color = gl_xml_get_prop_uint (node, "fill_color", 0);
 
 	gl_label_object_set_size (GL_LABEL_OBJECT(object), w, h);
 	gl_label_object_set_line_width (GL_LABEL_OBJECT(object), line_width);
-	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color);
-	gl_label_object_set_fill_color (GL_LABEL_OBJECT(object), fill_color);
+	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), line_color_node);
+	gl_label_object_set_fill_color (GL_LABEL_OBJECT(object), fill_color_node);
 
+	gl_color_node_free (&line_color_node);
+	gl_color_node_free (&fill_color_node);
 	gl_debug (DEBUG_XML, "END");
 
 	return GL_LABEL_OBJECT(object);
@@ -477,14 +494,14 @@ xml191_parse_image_props (xmlNodePtr  node,
 
 	filename = g_new0 (glTextNode, 1);
 	for (child = node->xmlChildrenNode; child != NULL; child = child->next) {
-		if (xmlStrEqual (child->name, "Field")) {
+		if (xmlStrEqual (child->name, (xmlChar *)"Field")) {
 			filename->field_flag = TRUE;
-			filename->data = xmlGetProp (child, "name");
-		} else if (xmlStrEqual (child->name, "File")) {
+			filename->data = (gchar *)xmlGetProp (child, (xmlChar *)"name");
+		} else if (xmlStrEqual (child->name, (xmlChar *)"File")) {
 			filename->field_flag = FALSE;
-			filename->data = xmlGetProp (child, "src");
+			filename->data = (gchar *)xmlGetProp (child, (xmlChar *)"src");
 		} else if (!xmlNodeIsText (child)) {
-			g_warning ("Unexpected Image child: \"%s\"", child->name);
+			g_message ("Unexpected Image child: \"%s\"", child->name);
 		}
 	}
 
@@ -508,12 +525,11 @@ xml191_parse_barcode_props (xmlNodePtr  node,
 	GObject            *object;
 	xmlNodePtr          child;
 	gdouble             w, h;
-	gchar              *string;
 	glTextNode         *text_node;
-	gchar              *id;
+	xmlChar            *id;
 	gboolean            text_flag;
 	gboolean            checksum_flag;
-	guint               color;
+	glColorNode        *color_node;
 
 	gl_debug (DEBUG_XML, "START");
 
@@ -522,23 +538,24 @@ xml191_parse_barcode_props (xmlNodePtr  node,
 	w = gl_xml_get_prop_length (node, "w", 0);
 	h = gl_xml_get_prop_length (node, "h", 0);
 
-	color = gl_xml_get_prop_uint (node, "color", 0);
+	color_node = gl_color_node_new_default ();
+	color_node->color = gl_xml_get_prop_uint (node, "color", 0);
 
-	id = xmlGetProp (node, "style");
+	id = xmlGetProp (node, (xmlChar *)"style");
 
 	text_flag = gl_xml_get_prop_boolean (node, "text", FALSE);
 	checksum_flag = gl_xml_get_prop_boolean (node, "checksum", TRUE);
 
 	text_node = g_new0 (glTextNode, 1);
 	for (child = node->xmlChildrenNode; child != NULL; child = child->next) {
-		if (xmlStrEqual (child->name, "Field")) {
+		if (xmlStrEqual (child->name, (xmlChar *)"Field")) {
 			text_node->field_flag = TRUE;
-			text_node->data = xmlGetProp (child, "name");
-		} else if (xmlStrEqual (child->name, "Literal")) {
+			text_node->data = (gchar *)xmlGetProp (child, (xmlChar *)"name");
+		} else if (xmlStrEqual (child->name, (xmlChar *)"Literal")) {
 			text_node->field_flag = FALSE;
-			text_node->data = xmlNodeGetContent (child);
+			text_node->data = (gchar *)xmlNodeGetContent (child);
 		} else if (!xmlNodeIsText (child)) {
-			g_warning ("Unexpected Barcode child: \"%s\"", child->name);
+			g_message ("Unexpected Barcode child: \"%s\"", child->name);
 		}
 	}
 
@@ -546,11 +563,12 @@ xml191_parse_barcode_props (xmlNodePtr  node,
 
 	gl_label_barcode_set_data (GL_LABEL_BARCODE(object), text_node);
 	gl_label_barcode_set_props (GL_LABEL_BARCODE(object),
-				    id, text_flag, checksum_flag, 0);
-	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), color);
+				    (gchar *)id, text_flag, checksum_flag, 0);
+	gl_label_object_set_line_color (GL_LABEL_OBJECT(object), color_node);
 
+	gl_color_node_free (&color_node);	
 	gl_text_node_free (&text_node);
-	g_free (id);
+	xmlFree (id);
 
 	gl_debug (DEBUG_XML, "END");
 
@@ -565,18 +583,18 @@ xml191_parse_merge_fields (xmlNodePtr  node,
 			   glLabel    *label)
 {
 	xmlNodePtr  child;
-	gchar      *string;
+	xmlChar    *string;
 	glMerge    *merge;
 
 	gl_debug (DEBUG_XML, "START");
 
-	string = xmlGetProp (node, "type");
-	merge = gl_merge_new (string);
-	g_free (string);
+	string = xmlGetProp (node, (xmlChar *)"type");
+	merge = gl_merge_new ((gchar *)string);
+	xmlFree (string);
 
-	string = xmlGetProp (node, "src");
-	gl_merge_set_src (merge, string);
-	g_free (string);
+	string = xmlGetProp (node, (xmlChar *)"src");
+	gl_merge_set_src (merge, (gchar *)string);
+	xmlFree (string);
 
 	gl_label_set_merge (label, merge);
 
@@ -598,11 +616,11 @@ xml191_parse_data (xmlNodePtr  node,
 
 	for (child = node->xmlChildrenNode; child != NULL; child = child->next) {
 
-		if (xmlStrEqual (child->name, "Pixdata")) {
+		if (xmlStrEqual (child->name, (xmlChar *)"Pixdata")) {
 			xml191_parse_pixdata (child, label);
 		} else {
 			if (!xmlNodeIsText (child)) {
-				g_warning (_("bad node in Data node =  \"%s\""),
+				g_message (_("bad node in Data node =  \"%s\""),
 					   child->name);
 			}
 		}
@@ -618,7 +636,7 @@ static void
 xml191_parse_pixdata (xmlNodePtr  node,
 		      glLabel    *label)
 {
-	gchar      *name, *base64;
+	xmlChar    *name, *base64;
 	guchar     *stream;
 	guint       stream_length;
 	gboolean    ret;
@@ -628,10 +646,10 @@ xml191_parse_pixdata (xmlNodePtr  node,
 
 	gl_debug (DEBUG_XML, "START");
 
-	name = xmlGetProp (node, "name");
+	name = xmlGetProp (node, (xmlChar *)"name");
 	base64 = xmlNodeGetContent (node);
 
-	stream = gl_base64_decode (base64, &stream_length);
+	stream = gl_base64_decode ((gchar *)base64, &stream_length);
 	pixdata = g_new0 (GdkPixdata, 1);
 	ret = gdk_pixdata_deserialize (pixdata, stream_length, stream, NULL);
 
@@ -639,11 +657,12 @@ xml191_parse_pixdata (xmlNodePtr  node,
 		pixbuf = gdk_pixbuf_from_pixdata (pixdata, TRUE, NULL);
 
 		pixbuf_cache = gl_label_get_pixbuf_cache (label);
-		gl_pixbuf_cache_add_pixbuf (pixbuf_cache, name, pixbuf);
+		gl_pixbuf_cache_add_pixbuf (pixbuf_cache, (gchar *)name, pixbuf);
 	}
 
-	g_free (name);
-	g_free (base64);
+	xmlFree (name);
+	xmlFree (base64);
+
 	g_free (stream);
 	g_free (pixdata);
 
@@ -656,7 +675,7 @@ xml191_parse_pixdata (xmlNodePtr  node,
 static glTemplate *
 xml191_parse_sheet (xmlNodePtr sheet_node)
 {
-	gchar                 *name, *description, *page_size;
+	xmlChar               *name, *description, *page_size;
 	gdouble                page_width, page_height;
 	glTemplate            *template;
 	xmlNodePtr             node;
@@ -664,10 +683,10 @@ xml191_parse_sheet (xmlNodePtr sheet_node)
 
 	gl_debug (DEBUG_TEMPLATE, "START");
 
-	name  = xmlGetProp (sheet_node, "name");
+	name  = xmlGetProp (sheet_node, (xmlChar *)"name");
 
-	page_size = xmlGetProp (sheet_node, "size");
-	if (gl_paper_is_id_other (page_size)) {
+	page_size = xmlGetProp (sheet_node, (xmlChar *)"size");
+	if (gl_paper_is_id_other ((gchar *)page_size)) {
 
 		page_width = gl_xml_get_prop_length (sheet_node, "width", 0);
 		page_height = gl_xml_get_prop_length (sheet_node, "height", 0);
@@ -677,7 +696,7 @@ xml191_parse_sheet (xmlNodePtr sheet_node)
 		if (paper == NULL) {
 			/* This should always be an id, but just in case a name
 			   slips by! */
-			g_warning (_("Unknown page size id \"%s\", trying as name"),
+			g_message (_("Unknown page size id \"%s\", trying as name"),
 				   template->page_size);
 			paper = gl_paper_from_name (template->page_size);
 			g_free (template->page_size);
@@ -687,47 +706,47 @@ xml191_parse_sheet (xmlNodePtr sheet_node)
 			page_width  = paper->width;
 			page_height = paper->height;
 		} else {
-			g_warning (_("Unknown page size id or name \"%s\""),
+			g_message (_("Unknown page size id or name \"%s\""),
 				   page_size);
 		}
 		gl_paper_free (paper);
 	}
 
-	description = xmlGetProp (sheet_node, "_description");
+	description = xmlGetProp (sheet_node, (xmlChar *)"_description");
 	if (description != NULL) {
 
-		gchar *tmp = gettext (description);
+		xmlChar *tmp = (xmlChar *)gettext ((char *)description);
 
 		if (tmp == description) {
-			template->description = description;
+			template->description = (gchar *)description;
 		} else {
-			template->description = g_strdup (tmp);
+			template->description = g_strdup ((gchar *)tmp);
 		}
 
 
 	} else {
-		template->description = xmlGetProp (sheet_node, "description");
+		template->description = (gchar *)xmlGetProp (sheet_node, (xmlChar *)"description");
 	}
 
-	template = gl_template_new (name, description,
-				    page_size, page_width, page_height);
+	template = gl_template_new ((gchar *)name, (gchar *)description,
+				    (gchar *)page_size, page_width, page_height);
 
 	for (node = sheet_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
-		if (xmlStrEqual (node->name, "Label")) {
+		if (xmlStrEqual (node->name, (xmlChar *)"Label")) {
 			xml191_parse_label (node, template);
-		} else if (xmlStrEqual (node->name, "Alias")) {
+		} else if (xmlStrEqual (node->name, (xmlChar *)"Alias")) {
 			xml191_parse_alias (node, template);
 		} else {
 			if (!xmlNodeIsText (node)) {
-				g_warning ("bad node =  \"%s\"", node->name);
+				g_message ("bad node =  \"%s\"", node->name);
 			}
 		}
 	}
 
-	g_free (name);
-	g_free (description);
-	g_free (page_size);
+	xmlFree (name);
+	xmlFree (description);
+	xmlFree (page_size);
 
 	gl_debug (DEBUG_TEMPLATE, "END");
 
@@ -741,7 +760,7 @@ static void
 xml191_parse_label (xmlNodePtr  label_node,
 		    glTemplate *template)
 {
-	gchar                *style;
+	xmlChar              *style;
 	glTemplateLabelShape  shape;
 	gdouble               w, h, r, r1, r2;
 	glTemplateLabelType  *label_type;
@@ -749,18 +768,18 @@ xml191_parse_label (xmlNodePtr  label_node,
 
 	gl_debug (DEBUG_TEMPLATE, "START");
 
-	style = xmlGetProp (label_node, "style");
-	if (xmlStrEqual (style, "rectangle")) {
+	style = xmlGetProp (label_node, (xmlChar *)"style");
+	if (xmlStrEqual (style, (xmlChar *)"rectangle")) {
 		shape = GL_TEMPLATE_SHAPE_RECT;
-	} else if (xmlStrEqual (style, "round")) {
+	} else if (xmlStrEqual (style, (xmlChar *)"round")) {
 		shape = GL_TEMPLATE_SHAPE_ROUND;
-	} else if (xmlStrEqual (style, "cd")) {
+	} else if (xmlStrEqual (style, (xmlChar *)"cd")) {
 		shape = GL_TEMPLATE_SHAPE_CD;
 	} else {
 		shape = GL_TEMPLATE_SHAPE_RECT;
-		g_warning ("Unknown label style in template");
+		g_message ("Unknown label style in template");
 	}
-	g_free (style);
+	xmlFree (style);
 
 	switch (shape) {
 
@@ -796,12 +815,12 @@ xml191_parse_label (xmlNodePtr  label_node,
 
 	for (node = label_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
-		if (xmlStrEqual (node->name, "Layout")) {
+		if (xmlStrEqual (node->name, (xmlChar *)"Layout")) {
 			xml191_parse_layout (node, label_type);
-		} else if (xmlStrEqual (node->name, "Markup")) {
+		} else if (xmlStrEqual (node->name, (xmlChar *)"Markup")) {
 			xml191_parse_markup (node, label_type);
 		} else if (!xmlNodeIsText (node)) {
-			g_warning ("bad node =  \"%s\"", node->name);
+			g_message ("bad node =  \"%s\"", node->name);
 		}
 	}
 
@@ -833,7 +852,7 @@ xml191_parse_layout (xmlNodePtr           layout_node,
 	for (node = layout_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
 		if (!xmlNodeIsText (node)) {
-			g_warning ("bad node =  \"%s\"", node->name);
+			g_message ("bad node =  \"%s\"", node->name);
 		}
 	}
 
@@ -850,22 +869,22 @@ static void
 xml191_parse_markup (xmlNodePtr  markup_node,
 		     glTemplateLabelType *label_type)
 {
-	gchar      *type;
+	xmlChar    *type;
 	gdouble     size;
 	gdouble     x1, y1, x2, y2;
 	xmlNodePtr  node;
 
 	gl_debug (DEBUG_TEMPLATE, "START");
 
-	type = xmlGetProp (markup_node, "type");
-	if (xmlStrEqual (type, "margin")) {
+	type = xmlGetProp (markup_node, (xmlChar *)"type");
+	if (xmlStrEqual (type, (xmlChar *)"margin")) {
 
 		size = gl_xml_get_prop_length (markup_node, "size", 0);
 
 		gl_template_add_markup (label_type,
 					gl_template_markup_margin_new (size));
 
-	} else if (xmlStrEqual (type, "line")) {
+	} else if (xmlStrEqual (type, (xmlChar *)"line")) {
 
 		x1 = gl_xml_get_prop_length (markup_node, "x1", 0);
 		y1 = gl_xml_get_prop_length (markup_node, "y1", 0);
@@ -875,12 +894,12 @@ xml191_parse_markup (xmlNodePtr  markup_node,
 		gl_template_add_markup (label_type,
 					gl_template_markup_line_new (x1, y1, x2, y2));
 	}
-	g_free (type);
+	xmlFree (type);
 
 	for (node = markup_node->xmlChildrenNode; node != NULL;
 	     node = node->next) {
 		if (!xmlNodeIsText (node)) {
-			g_warning ("bad node =  \"%s\"", node->name);
+			g_message ("bad node =  \"%s\"", node->name);
 		}
 	}
 
@@ -894,14 +913,13 @@ static void
 xml191_parse_alias (xmlNodePtr  alias_node,
 		    glTemplate *template)
 {
-	gchar       *name;
+	xmlChar    *name;
 
 	gl_debug (DEBUG_TEMPLATE, "START");
 
-	name = xmlGetProp (alias_node, "name");
-	gl_template_add_alias (template, name);
-	g_free (name);
+	name = xmlGetProp (alias_node, (xmlChar *)"name");
+	gl_template_add_alias (template, (gchar *)name);
+	xmlFree (name);
 
 	gl_debug (DEBUG_TEMPLATE, "END");
 }
-
